@@ -18,6 +18,7 @@ IdempotencyToken = str
 MaxItems = int
 NextToken = str
 NullableBoolean = bool
+PcaArn = str
 PositiveInteger = int
 PrivateKey = str
 ServiceErrorMessage = str
@@ -499,8 +500,9 @@ class RequestCertificateRequest(ServiceRequest):
     IdempotencyToken: Optional[IdempotencyToken]
     DomainValidationOptions: Optional[DomainValidationOptionList]
     Options: Optional[CertificateOptions]
-    CertificateAuthorityArn: Optional[Arn]
+    CertificateAuthorityArn: Optional[PcaArn]
     Tags: Optional[TagList]
+    KeyAlgorithm: Optional[KeyAlgorithm]
 
 
 class RequestCertificateResponse(TypedDict, total=False):
@@ -618,8 +620,9 @@ class AcmApi:
         idempotency_token: IdempotencyToken = None,
         domain_validation_options: DomainValidationOptionList = None,
         options: CertificateOptions = None,
-        certificate_authority_arn: Arn = None,
+        certificate_authority_arn: PcaArn = None,
         tags: TagList = None,
+        key_algorithm: KeyAlgorithm = None,
     ) -> RequestCertificateResponse:
         raise NotImplementedError
 
