@@ -46,6 +46,7 @@ GetMetricDataMaxDatapoints = int
 HistoryData = str
 HistorySummary = str
 IncludeLinkedAccounts = bool
+IncludeLinkedAccountsMetrics = bool
 InsightRuleAggregationStatistic = str
 InsightRuleContributorKey = str
 InsightRuleContributorKeyLabel = str
@@ -125,6 +126,10 @@ class ComparisonOperator(str):
     GreaterThanUpperThreshold = "GreaterThanUpperThreshold"
 
 
+class EvaluationState(str):
+    PARTIAL_DATA = "PARTIAL_DATA"
+
+
 class HistoryItemType(str):
     ConfigurationUpdate = "ConfigurationUpdate"
     StateUpdate = "StateUpdate"
@@ -539,6 +544,8 @@ class MetricAlarm(TypedDict, total=False):
     EvaluateLowSampleCountPercentile: Optional[EvaluateLowSampleCountPercentile]
     Metrics: Optional[MetricDataQueries]
     ThresholdMetricId: Optional[MetricId]
+    EvaluationState: Optional[EvaluationState]
+    StateTransitionedTimestamp: Optional[Timestamp]
 
 
 MetricAlarms = List[MetricAlarm]
@@ -805,6 +812,7 @@ class GetMetricStreamOutput(TypedDict, total=False):
     LastUpdateDate: Optional[Timestamp]
     OutputFormat: Optional[MetricStreamOutputFormat]
     StatisticsConfigurations: Optional[MetricStreamStatisticsConfigurations]
+    IncludeLinkedAccountsMetrics: Optional[IncludeLinkedAccountsMetrics]
 
 
 class GetMetricWidgetImageInput(ServiceRequest):
@@ -1041,6 +1049,7 @@ class PutMetricStreamInput(ServiceRequest):
     OutputFormat: MetricStreamOutputFormat
     Tags: Optional[TagList]
     StatisticsConfigurations: Optional[MetricStreamStatisticsConfigurations]
+    IncludeLinkedAccountsMetrics: Optional[IncludeLinkedAccountsMetrics]
 
 
 class PutMetricStreamOutput(TypedDict, total=False):
@@ -1433,6 +1442,7 @@ class CloudwatchApi:
         exclude_filters: MetricStreamFilters = None,
         tags: TagList = None,
         statistics_configurations: MetricStreamStatisticsConfigurations = None,
+        include_linked_accounts_metrics: IncludeLinkedAccountsMetrics = None,
     ) -> PutMetricStreamOutput:
         raise NotImplementedError
 
