@@ -10,10 +10,12 @@ else:
 from localstack.aws.api import RequestContext, ServiceException, ServiceRequest, handler
 
 ARN = str
+AWSAccount = str
 BackendRole = str
 Boolean = bool
 ChangeProgressStageName = str
 ChangeProgressStageStatus = str
+ClientToken = str
 CloudWatchLogsLogGroupArn = str
 CommitMessage = str
 ConnectionAlias = str
@@ -22,12 +24,14 @@ CrossClusterSearchConnectionStatusMessage = str
 DeploymentType = str
 DescribePackagesFilterValue = str
 Description = str
+DomainArn = str
 DomainId = str
 DomainName = str
 DomainNameFqdn = str
 Double = float
 DryRun = bool
 ElasticsearchVersionString = str
+Endpoint = str
 ErrorMessage = str
 ErrorType = str
 GUID = str
@@ -73,6 +77,7 @@ UIntValue = int
 UpgradeName = str
 UserPoolId = str
 Username = str
+VpcEndpointId = str
 
 
 class AutoTuneDesiredState(str):
@@ -244,6 +249,11 @@ class PackageType(str):
     TXT_DICTIONARY = "TXT-DICTIONARY"
 
 
+class PrincipalType(str):
+    AWS_ACCOUNT = "AWS_ACCOUNT"
+    AWS_SERVICE = "AWS_SERVICE"
+
+
 class ReservedElasticsearchInstancePaymentOption(str):
     ALL_UPFRONT = "ALL_UPFRONT"
     PARTIAL_UPFRONT = "PARTIAL_UPFRONT"
@@ -295,6 +305,21 @@ class VolumeType(str):
     gp3 = "gp3"
 
 
+class VpcEndpointErrorCode(str):
+    ENDPOINT_NOT_FOUND = "ENDPOINT_NOT_FOUND"
+    SERVER_ERROR = "SERVER_ERROR"
+
+
+class VpcEndpointStatus(str):
+    CREATING = "CREATING"
+    CREATE_FAILED = "CREATE_FAILED"
+    ACTIVE = "ACTIVE"
+    UPDATING = "UPDATING"
+    UPDATE_FAILED = "UPDATE_FAILED"
+    DELETING = "DELETING"
+    DELETE_FAILED = "DELETE_FAILED"
+
+
 class AccessDeniedException(ServiceException):
     code: str = "AccessDeniedException"
     sender_fault: bool = False
@@ -515,6 +540,21 @@ class AssociatePackageResponse(TypedDict, total=False):
     DomainPackageDetails: Optional[DomainPackageDetails]
 
 
+class AuthorizeVpcEndpointAccessRequest(ServiceRequest):
+    DomainName: DomainName
+    Account: AWSAccount
+
+
+class AuthorizedPrincipal(TypedDict, total=False):
+    PrincipalType: Optional[PrincipalType]
+    Principal: Optional[String]
+
+
+class AuthorizeVpcEndpointAccessResponse(TypedDict, total=False):
+    AuthorizedPrincipal: AuthorizedPrincipal
+
+
+AuthorizedPrincipalList = List[AuthorizedPrincipal]
 AutoTuneDate = datetime
 
 
@@ -831,6 +871,25 @@ class CreatePackageResponse(TypedDict, total=False):
     PackageDetails: Optional[PackageDetails]
 
 
+class CreateVpcEndpointRequest(ServiceRequest):
+    DomainArn: DomainArn
+    VpcOptions: VPCOptions
+    ClientToken: Optional[ClientToken]
+
+
+class VpcEndpoint(TypedDict, total=False):
+    VpcEndpointId: Optional[VpcEndpointId]
+    VpcEndpointOwner: Optional[AWSAccount]
+    DomainArn: Optional[DomainArn]
+    VpcOptions: Optional[VPCDerivedInfo]
+    Status: Optional[VpcEndpointStatus]
+    Endpoint: Optional[Endpoint]
+
+
+class CreateVpcEndpointResponse(TypedDict, total=False):
+    VpcEndpoint: VpcEndpoint
+
+
 class DeleteElasticsearchDomainRequest(ServiceRequest):
     DomainName: DomainName
 
@@ -871,6 +930,21 @@ class DeletePackageResponse(TypedDict, total=False):
     PackageDetails: Optional[PackageDetails]
 
 
+class DeleteVpcEndpointRequest(ServiceRequest):
+    VpcEndpointId: VpcEndpointId
+
+
+class VpcEndpointSummary(TypedDict, total=False):
+    VpcEndpointId: Optional[VpcEndpointId]
+    VpcEndpointOwner: Optional[String]
+    DomainArn: Optional[DomainArn]
+    Status: Optional[VpcEndpointStatus]
+
+
+class DeleteVpcEndpointResponse(TypedDict, total=False):
+    VpcEndpointSummary: VpcEndpointSummary
+
+
 class DescribeDomainAutoTunesRequest(ServiceRequest):
     DomainName: DomainName
     MaxResults: Optional[MaxResults]
@@ -1156,6 +1230,28 @@ class DescribeReservedElasticsearchInstancesResponse(TypedDict, total=False):
     ReservedElasticsearchInstances: Optional[ReservedElasticsearchInstanceList]
 
 
+VpcEndpointIdList = List[VpcEndpointId]
+
+
+class DescribeVpcEndpointsRequest(ServiceRequest):
+    VpcEndpointIds: VpcEndpointIdList
+
+
+class VpcEndpointError(TypedDict, total=False):
+    VpcEndpointId: Optional[VpcEndpointId]
+    ErrorCode: Optional[VpcEndpointErrorCode]
+    ErrorMessage: Optional[String]
+
+
+VpcEndpointErrorList = List[VpcEndpointError]
+VpcEndpoints = List[VpcEndpoint]
+
+
+class DescribeVpcEndpointsResponse(TypedDict, total=False):
+    VpcEndpoints: VpcEndpoints
+    VpcEndpointErrors: VpcEndpointErrorList
+
+
 class DissociatePackageRequest(ServiceRequest):
     PackageID: PackageID
     DomainName: DomainName
@@ -1316,6 +1412,38 @@ class ListTagsResponse(TypedDict, total=False):
     TagList: Optional[TagList]
 
 
+class ListVpcEndpointAccessRequest(ServiceRequest):
+    DomainName: DomainName
+    NextToken: Optional[NextToken]
+
+
+class ListVpcEndpointAccessResponse(TypedDict, total=False):
+    AuthorizedPrincipalList: AuthorizedPrincipalList
+    NextToken: NextToken
+
+
+class ListVpcEndpointsForDomainRequest(ServiceRequest):
+    DomainName: DomainName
+    NextToken: Optional[NextToken]
+
+
+VpcEndpointSummaryList = List[VpcEndpointSummary]
+
+
+class ListVpcEndpointsForDomainResponse(TypedDict, total=False):
+    VpcEndpointSummaryList: VpcEndpointSummaryList
+    NextToken: NextToken
+
+
+class ListVpcEndpointsRequest(ServiceRequest):
+    NextToken: Optional[NextToken]
+
+
+class ListVpcEndpointsResponse(TypedDict, total=False):
+    VpcEndpointSummaryList: VpcEndpointSummaryList
+    NextToken: NextToken
+
+
 class PurchaseReservedElasticsearchInstanceOfferingRequest(ServiceRequest):
     ReservedElasticsearchInstanceOfferingId: GUID
     ReservationName: ReservationToken
@@ -1340,6 +1468,15 @@ class RemoveTagsRequest(ServiceRequest):
     TagKeys: StringList
 
 
+class RevokeVpcEndpointAccessRequest(ServiceRequest):
+    DomainName: DomainName
+    Account: AWSAccount
+
+
+class RevokeVpcEndpointAccessResponse(TypedDict, total=False):
+    pass
+
+
 class StartElasticsearchServiceSoftwareUpdateRequest(ServiceRequest):
     DomainName: DomainName
 
@@ -1382,6 +1519,15 @@ class UpdatePackageResponse(TypedDict, total=False):
     PackageDetails: Optional[PackageDetails]
 
 
+class UpdateVpcEndpointRequest(ServiceRequest):
+    VpcEndpointId: VpcEndpointId
+    VpcOptions: VPCOptions
+
+
+class UpdateVpcEndpointResponse(TypedDict, total=False):
+    VpcEndpoint: VpcEndpoint
+
+
 class UpgradeElasticsearchDomainRequest(ServiceRequest):
     DomainName: DomainName
     TargetVersion: ElasticsearchVersionString
@@ -1418,6 +1564,12 @@ class EsApi:
     ) -> AssociatePackageResponse:
         raise NotImplementedError
 
+    @handler("AuthorizeVpcEndpointAccess")
+    def authorize_vpc_endpoint_access(
+        self, context: RequestContext, domain_name: DomainName, account: AWSAccount
+    ) -> AuthorizeVpcEndpointAccessResponse:
+        raise NotImplementedError
+
     @handler("CancelElasticsearchServiceSoftwareUpdate")
     def cancel_elasticsearch_service_software_update(
         self, context: RequestContext, domain_name: DomainName
@@ -1468,6 +1620,16 @@ class EsApi:
     ) -> CreatePackageResponse:
         raise NotImplementedError
 
+    @handler("CreateVpcEndpoint")
+    def create_vpc_endpoint(
+        self,
+        context: RequestContext,
+        domain_arn: DomainArn,
+        vpc_options: VPCOptions,
+        client_token: ClientToken = None,
+    ) -> CreateVpcEndpointResponse:
+        raise NotImplementedError
+
     @handler("DeleteElasticsearchDomain")
     def delete_elasticsearch_domain(
         self, context: RequestContext, domain_name: DomainName
@@ -1503,6 +1665,12 @@ class EsApi:
     ) -> DeletePackageResponse:
         raise NotImplementedError
 
+    @handler("DeleteVpcEndpoint")
+    def delete_vpc_endpoint(
+        self, context: RequestContext, vpc_endpoint_id: VpcEndpointId
+    ) -> DeleteVpcEndpointResponse:
+        raise NotImplementedError
+
     @handler("DescribeDomainAutoTunes")
     def describe_domain_auto_tunes(
         self,
@@ -1597,6 +1765,12 @@ class EsApi:
     ) -> DescribeReservedElasticsearchInstancesResponse:
         raise NotImplementedError
 
+    @handler("DescribeVpcEndpoints")
+    def describe_vpc_endpoints(
+        self, context: RequestContext, vpc_endpoint_ids: VpcEndpointIdList
+    ) -> DescribeVpcEndpointsResponse:
+        raise NotImplementedError
+
     @handler("DissociatePackage")
     def dissociate_package(
         self, context: RequestContext, package_id: PackageID, domain_name: DomainName
@@ -1682,6 +1856,24 @@ class EsApi:
     def list_tags(self, context: RequestContext, arn: ARN) -> ListTagsResponse:
         raise NotImplementedError
 
+    @handler("ListVpcEndpointAccess")
+    def list_vpc_endpoint_access(
+        self, context: RequestContext, domain_name: DomainName, next_token: NextToken = None
+    ) -> ListVpcEndpointAccessResponse:
+        raise NotImplementedError
+
+    @handler("ListVpcEndpoints")
+    def list_vpc_endpoints(
+        self, context: RequestContext, next_token: NextToken = None
+    ) -> ListVpcEndpointsResponse:
+        raise NotImplementedError
+
+    @handler("ListVpcEndpointsForDomain")
+    def list_vpc_endpoints_for_domain(
+        self, context: RequestContext, domain_name: DomainName, next_token: NextToken = None
+    ) -> ListVpcEndpointsForDomainResponse:
+        raise NotImplementedError
+
     @handler("PurchaseReservedElasticsearchInstanceOffering")
     def purchase_reserved_elasticsearch_instance_offering(
         self,
@@ -1704,6 +1896,12 @@ class EsApi:
     def remove_tags(self, context: RequestContext, arn: ARN, tag_keys: StringList) -> None:
         raise NotImplementedError
 
+    @handler("RevokeVpcEndpointAccess")
+    def revoke_vpc_endpoint_access(
+        self, context: RequestContext, domain_name: DomainName, account: AWSAccount
+    ) -> RevokeVpcEndpointAccessResponse:
+        raise NotImplementedError
+
     @handler("StartElasticsearchServiceSoftwareUpdate")
     def start_elasticsearch_service_software_update(
         self, context: RequestContext, domain_name: DomainName
@@ -1743,6 +1941,12 @@ class EsApi:
     ) -> UpdatePackageResponse:
         raise NotImplementedError
 
+    @handler("UpdateVpcEndpoint")
+    def update_vpc_endpoint(
+        self, context: RequestContext, vpc_endpoint_id: VpcEndpointId, vpc_options: VPCOptions
+    ) -> UpdateVpcEndpointResponse:
+        raise NotImplementedError
+
     @handler("UpgradeElasticsearchDomain")
     def upgrade_elasticsearch_domain(
         self,
