@@ -17,6 +17,7 @@ GroupConfigurationParameterName = str
 GroupConfigurationParameterValue = str
 GroupConfigurationType = str
 GroupFilterValue = str
+GroupLifecycleEventsStatusMessage = str
 GroupName = str
 GroupString = str
 MaxResults = int
@@ -41,9 +42,22 @@ class GroupFilterName(str):
     configuration_type = "configuration-type"
 
 
+class GroupLifecycleEventsDesiredStatus(str):
+    ACTIVE = "ACTIVE"
+    INACTIVE = "INACTIVE"
+
+
+class GroupLifecycleEventsStatus(str):
+    ACTIVE = "ACTIVE"
+    INACTIVE = "INACTIVE"
+    IN_PROGRESS = "IN_PROGRESS"
+    ERROR = "ERROR"
+
+
 class QueryErrorCode(str):
     CLOUDFORMATION_STACK_INACTIVE = "CLOUDFORMATION_STACK_INACTIVE"
     CLOUDFORMATION_STACK_NOT_EXISTING = "CLOUDFORMATION_STACK_NOT_EXISTING"
+    CLOUDFORMATION_STACK_UNASSUMABLE_ROLE = "CLOUDFORMATION_STACK_UNASSUMABLE_ROLE"
 
 
 class QueryType(str):
@@ -63,49 +77,48 @@ class BadRequestException(ServiceException):
     code: str = "BadRequestException"
     sender_fault: bool = False
     status_code: int = 400
-    Message: Optional[ErrorMessage]
 
 
 class ForbiddenException(ServiceException):
     code: str = "ForbiddenException"
     sender_fault: bool = False
     status_code: int = 403
-    Message: Optional[ErrorMessage]
 
 
 class InternalServerErrorException(ServiceException):
     code: str = "InternalServerErrorException"
     sender_fault: bool = False
     status_code: int = 500
-    Message: Optional[ErrorMessage]
 
 
 class MethodNotAllowedException(ServiceException):
     code: str = "MethodNotAllowedException"
     sender_fault: bool = False
     status_code: int = 405
-    Message: Optional[ErrorMessage]
 
 
 class NotFoundException(ServiceException):
     code: str = "NotFoundException"
     sender_fault: bool = False
     status_code: int = 404
-    Message: Optional[ErrorMessage]
 
 
 class TooManyRequestsException(ServiceException):
     code: str = "TooManyRequestsException"
     sender_fault: bool = False
     status_code: int = 429
-    Message: Optional[ErrorMessage]
 
 
 class UnauthorizedException(ServiceException):
     code: str = "UnauthorizedException"
     sender_fault: bool = False
     status_code: int = 401
-    Message: Optional[ErrorMessage]
+
+
+class AccountSettings(TypedDict, total=False):
+    GroupLifecycleEventsDesiredStatus: Optional[GroupLifecycleEventsDesiredStatus]
+    GroupLifecycleEventsStatus: Optional[GroupLifecycleEventsStatus]
+    GroupLifecycleEventsStatusMessage: Optional[GroupLifecycleEventsStatusMessage]
 
 
 GroupConfigurationParameterValueList = List[GroupConfigurationParameterValue]
@@ -179,6 +192,10 @@ class FailedResource(TypedDict, total=False):
 FailedResourceList = List[FailedResource]
 
 
+class GetAccountSettingsOutput(TypedDict, total=False):
+    AccountSettings: Optional[AccountSettings]
+
+
 class GetGroupConfigurationInput(ServiceRequest):
     Group: Optional[GroupString]
 
@@ -377,6 +394,14 @@ class UntagOutput(TypedDict, total=False):
     Keys: Optional[TagKeyList]
 
 
+class UpdateAccountSettingsInput(ServiceRequest):
+    GroupLifecycleEventsDesiredStatus: Optional[GroupLifecycleEventsDesiredStatus]
+
+
+class UpdateAccountSettingsOutput(TypedDict, total=False):
+    AccountSettings: Optional[AccountSettings]
+
+
 class UpdateGroupInput(ServiceRequest):
     GroupName: Optional[GroupName]
     Group: Optional[GroupString]
@@ -420,6 +445,13 @@ class ResourceGroupsApi:
     ) -> DeleteGroupOutput:
         raise NotImplementedError
 
+    @handler("GetAccountSettings")
+    def get_account_settings(
+        self,
+        context: RequestContext,
+    ) -> GetAccountSettingsOutput:
+        raise NotImplementedError
+
     @handler("GetGroup")
     def get_group(
         self, context: RequestContext, group_name: GroupName = None, group: GroupString = None
@@ -503,6 +535,14 @@ class ResourceGroupsApi:
     def untag(self, context: RequestContext, arn: GroupArn, keys: TagKeyList) -> UntagOutput:
         raise NotImplementedError
 
+    @handler("UpdateAccountSettings")
+    def update_account_settings(
+        self,
+        context: RequestContext,
+        group_lifecycle_events_desired_status: GroupLifecycleEventsDesiredStatus = None,
+    ) -> UpdateAccountSettingsOutput:
+        raise NotImplementedError
+
     @handler("UpdateGroup")
     def update_group(
         self,
