@@ -51,12 +51,14 @@ MaxResults = int
 MinStorageBytesPercentage = float
 MultiRegionAccessPointAlias = str
 MultiRegionAccessPointClientToken = str
+MultiRegionAccessPointId = str
 MultiRegionAccessPointName = str
 NoSuchPublicAccessBlockConfigurationMessage = str
 NonEmptyMaxLength1024String = str
 NonEmptyMaxLength2048String = str
 NonEmptyMaxLength256String = str
 NonEmptyMaxLength64String = str
+NoncurrentVersionCount = int
 ObjectLambdaAccessPointArn = str
 ObjectLambdaAccessPointName = str
 ObjectLambdaPolicy = str
@@ -83,6 +85,7 @@ StringForNextToken = str
 SuspendedCause = str
 TagKeyString = str
 TagValueString = str
+TrafficDialPercentage = int
 VpcId = str
 
 
@@ -196,10 +199,15 @@ class NetworkOrigin(str):
 class ObjectLambdaAllowedFeature(str):
     GetObject_Range = "GetObject-Range"
     GetObject_PartNumber = "GetObject-PartNumber"
+    HeadObject_Range = "HeadObject-Range"
+    HeadObject_PartNumber = "HeadObject-PartNumber"
 
 
 class ObjectLambdaTransformationConfigurationAction(str):
     GetObject = "GetObject"
+    HeadObject = "HeadObject"
+    ListObjects = "ListObjects"
+    ListObjectsV2 = "ListObjectsV2"
 
 
 class OperationName(str):
@@ -396,11 +404,24 @@ class AccessPoint(TypedDict, total=False):
     Bucket: BucketName
     AccessPointArn: Optional[S3AccessPointArn]
     Alias: Optional[Alias]
+    BucketAccountId: Optional[AccountId]
 
 
 AccessPointList = List[AccessPoint]
 
 
+class DetailedStatusCodesMetrics(TypedDict, total=False):
+    IsEnabled: Optional[IsEnabled]
+
+
+class AdvancedDataProtectionMetrics(TypedDict, total=False):
+    IsEnabled: Optional[IsEnabled]
+
+
+class AdvancedCostOptimizationMetrics(TypedDict, total=False):
+    IsEnabled: Optional[IsEnabled]
+
+
 class SelectionCriteria(TypedDict, total=False):
     Delimiter: Optional[StorageLensPrefixLevelDelimiter]
     MaxDepth: Optional[StorageLensPrefixLevelMaxDepth]
@@ -423,11 +444,17 @@ class ActivityMetrics(TypedDict, total=False):
 class BucketLevel(TypedDict, total=False):
     ActivityMetrics: Optional[ActivityMetrics]
     PrefixLevel: Optional[PrefixLevel]
+    AdvancedCostOptimizationMetrics: Optional[AdvancedCostOptimizationMetrics]
+    AdvancedDataProtectionMetrics: Optional[AdvancedDataProtectionMetrics]
+    DetailedStatusCodesMetrics: Optional[DetailedStatusCodesMetrics]
 
 
 class AccountLevel(TypedDict, total=False):
     ActivityMetrics: Optional[ActivityMetrics]
     BucketLevel: BucketLevel
+    AdvancedCostOptimizationMetrics: Optional[AdvancedCostOptimizationMetrics]
+    AdvancedDataProtectionMetrics: Optional[AdvancedDataProtectionMetrics]
+    DetailedStatusCodesMetrics: Optional[DetailedStatusCodesMetrics]
 
 
 AsyncCreationTimestamp = datetime
@@ -554,6 +581,7 @@ class CreateAccessPointRequest(ServiceRequest):
     Bucket: BucketName
     VpcConfiguration: Optional[VpcConfiguration]
     PublicAccessBlockConfiguration: Optional[PublicAccessBlockConfiguration]
+    BucketAccountId: Optional[AccountId]
 
 
 class CreateAccessPointResult(TypedDict, total=False):
@@ -1063,6 +1091,7 @@ class GetAccessPointResult(TypedDict, total=False):
     Alias: Optional[Alias]
     AccessPointArn: Optional[S3AccessPointArn]
     Endpoints: Optional[Endpoints]
+    BucketAccountId: Optional[AccountId]
 
 
 class GetBucketLifecycleConfigurationRequest(ServiceRequest):
@@ -1072,6 +1101,7 @@ class GetBucketLifecycleConfigurationRequest(ServiceRequest):
 
 class NoncurrentVersionExpiration(TypedDict, total=False):
     NoncurrentDays: Optional[Days]
+    NewerNoncurrentVersions: Optional[NoncurrentVersionCount]
 
 
 class NoncurrentVersionTransition(TypedDict, total=False):
@@ -1089,17 +1119,23 @@ class Transition(TypedDict, total=False):
 
 
 TransitionList = List[Transition]
+ObjectSizeLessThanBytes = int
+ObjectSizeGreaterThanBytes = int
 
 
 class LifecycleRuleAndOperator(TypedDict, total=False):
     Prefix: Optional[Prefix]
     Tags: Optional[S3TagSet]
+    ObjectSizeGreaterThan: Optional[ObjectSizeGreaterThanBytes]
+    ObjectSizeLessThan: Optional[ObjectSizeLessThanBytes]
 
 
 class LifecycleRuleFilter(TypedDict, total=False):
     Prefix: Optional[Prefix]
     Tag: Optional[S3Tag]
     And: Optional[LifecycleRuleAndOperator]
+    ObjectSizeGreaterThan: Optional[ObjectSizeGreaterThanBytes]
+    ObjectSizeLessThan: Optional[ObjectSizeLessThanBytes]
 
 
 class LifecycleExpiration(TypedDict, total=False):
@@ -1227,6 +1263,25 @@ class GetMultiRegionAccessPointResult(TypedDict, total=False):
     AccessPoint: Optional[MultiRegionAccessPointReport]
 
 
+class GetMultiRegionAccessPointRoutesRequest(ServiceRequest):
+    AccountId: AccountId
+    Mrap: MultiRegionAccessPointId
+
+
+class MultiRegionAccessPointRoute(TypedDict, total=False):
+    Bucket: Optional[BucketName]
+    Region: Optional[RegionName]
+    TrafficDialPercentage: TrafficDialPercentage
+
+
+RouteList = List[MultiRegionAccessPointRoute]
+
+
+class GetMultiRegionAccessPointRoutesResult(TypedDict, total=False):
+    Mrap: Optional[MultiRegionAccessPointId]
+    Routes: Optional[RouteList]
+
+
 class GetPublicAccessBlockOutput(TypedDict, total=False):
     PublicAccessBlockConfiguration: Optional[PublicAccessBlockConfiguration]
 
@@ -1522,6 +1577,16 @@ class PutStorageLensConfigurationTaggingResult(TypedDict, total=False):
     pass
 
 
+class SubmitMultiRegionAccessPointRoutesRequest(ServiceRequest):
+    AccountId: AccountId
+    Mrap: MultiRegionAccessPointId
+    RouteUpdates: RouteList
+
+
+class SubmitMultiRegionAccessPointRoutesResult(TypedDict, total=False):
+    pass
+
+
 class UpdateJobPriorityRequest(ServiceRequest):
     AccountId: AccountId
     JobId: JobId
@@ -1560,6 +1625,7 @@ class S3ControlApi:
         bucket: BucketName,
         vpc_configuration: VpcConfiguration = None,
         public_access_block_configuration: PublicAccessBlockConfiguration = None,
+        bucket_account_id: AccountId = None,
     ) -> CreateAccessPointResult:
         raise NotImplementedError
 
@@ -1809,6 +1875,12 @@ class S3ControlApi:
     ) -> GetMultiRegionAccessPointPolicyStatusResult:
         raise NotImplementedError
 
+    @handler("GetMultiRegionAccessPointRoutes")
+    def get_multi_region_access_point_routes(
+        self, context: RequestContext, account_id: AccountId, mrap: MultiRegionAccessPointId
+    ) -> GetMultiRegionAccessPointRoutesResult:
+        raise NotImplementedError
+
     @handler("GetPublicAccessBlock")
     def get_public_access_block(
         self, context: RequestContext, account_id: AccountId
@@ -1996,6 +2068,16 @@ class S3ControlApi:
     ) -> PutStorageLensConfigurationTaggingResult:
         raise NotImplementedError
 
+    @handler("SubmitMultiRegionAccessPointRoutes")
+    def submit_multi_region_access_point_routes(
+        self,
+        context: RequestContext,
+        account_id: AccountId,
+        mrap: MultiRegionAccessPointId,
+        route_updates: RouteList,
+    ) -> SubmitMultiRegionAccessPointRoutesResult:
+        raise NotImplementedError
+
     @handler("UpdateJobPriority")
     def update_job_priority(
         self, context: RequestContext, account_id: AccountId, job_id: JobId, priority: JobPriority
