@@ -50,6 +50,7 @@ class FilterNameStringType(str):
     tag_key = "tag-key"
     tag_value = "tag-value"
     primary_region = "primary-region"
+    owning_service = "owning-service"
     all = "all"
 
 
@@ -237,6 +238,7 @@ class DescribeSecretRequest(ServiceRequest):
 TimestampType = datetime
 SecretVersionStagesType = List[SecretVersionStageType]
 SecretVersionsToStagesMapType = Dict[SecretVersionIdType, SecretVersionStagesType]
+NextRotationDateType = datetime
 LastChangedDateType = datetime
 LastRotatedDateType = datetime
 
@@ -259,6 +261,7 @@ class DescribeSecretResponse(TypedDict, total=False):
     LastChangedDate: Optional[LastChangedDateType]
     LastAccessedDate: Optional[LastAccessedDateType]
     DeletedDate: Optional[DeletedDateType]
+    NextRotationDate: Optional[NextRotationDateType]
     Tags: Optional[TagListType]
     VersionIdsToStages: Optional[SecretVersionsToStagesMapType]
     OwningService: Optional[OwningServiceType]
@@ -349,6 +352,7 @@ class ListSecretVersionIdsResponse(TypedDict, total=False):
 
 
 class ListSecretsRequest(ServiceRequest):
+    IncludePlannedDeletion: Optional[BooleanType]
     MaxResults: Optional[MaxResultsType]
     NextToken: Optional[NextTokenType]
     Filters: Optional[FiltersListType]
@@ -367,6 +371,7 @@ class SecretListEntry(TypedDict, total=False):
     LastChangedDate: Optional[LastChangedDateType]
     LastAccessedDate: Optional[LastAccessedDateType]
     DeletedDate: Optional[DeletedDateType]
+    NextRotationDate: Optional[NextRotationDateType]
     Tags: Optional[TagListType]
     SecretVersionsToStages: Optional[SecretVersionsToStagesMapType]
     OwningService: Optional[OwningServiceType]
@@ -616,6 +621,7 @@ class SecretsmanagerApi:
     def list_secrets(
         self,
         context: RequestContext,
+        include_planned_deletion: BooleanType = None,
         max_results: MaxResultsType = None,
         next_token: NextTokenType = None,
         filters: FiltersListType = None,
