@@ -1,7 +1,11 @@
 import logging
 
-from localstack.aws.accounts import get_account_id_from_access_key_id, set_aws_access_key_id
-from localstack.constants import HEADER_LOCALSTACK_ACCOUNT_ID, TEST_AWS_ACCESS_KEY_ID
+from localstack.aws.accounts import (
+    get_account_id_from_access_key_id,
+    set_aws_access_key_id,
+    set_aws_account_id,
+)
+from localstack.constants import TEST_AWS_ACCESS_KEY_ID
 from localstack.http import Response
 from localstack.utils.aws.aws_stack import extract_access_key_id_from_auth_header
 
@@ -33,18 +37,18 @@ class AccountIdEnricher(Handler):
     """
 
     def __call__(self, chain: HandlerChain, context: RequestContext, response: Response):
-        access_key_id = extract_access_key_id_from_auth_header(context.request.headers)
-
-        if not access_key_id:
-            access_key_id = TEST_AWS_ACCESS_KEY_ID
-
-        # Save the request access key ID in the current thread local storage
+        # Obtain the access key ID and save it in the thread context
+        access_key_id = (
+            extract_access_key_id_from_auth_header(context.request.headers)
+            or TEST_AWS_ACCESS_KEY_ID
+        )
         set_aws_access_key_id(access_key_id)
 
-        if account_id_from_header := context.request.headers.get(HEADER_LOCALSTACK_ACCOUNT_ID):
-            context.account_id = account_id_from_header
-        else:
-            context.account_id = get_account_id_from_access_key_id(access_key_id)
+        # Obtain the account ID and save it in the request context
+        context.account_id = get_account_id_from_access_key_id(access_key_id)
+
+        # Save the same account ID in the thread context
+        set_aws_account_id(context.account_id)
 
         # Make Moto use the same Account ID as LocalStack
         context.request.headers.add("x-moto-account-id", context.account_id)
