@@ -62,6 +62,8 @@ words = [
     "latest",
 ]
 
+DEFAULT_ARN = "arn:aws:ec2:us-east-1:1234567890123:instance/i-abcde0123456789f"
+
 
 class ShapeGraph(networkx.DiGraph):
     root: Union[ListShape, StructureShape, MapShape]
@@ -127,6 +129,8 @@ def shape_graph(root: Shape) -> ShapeGraph:
 
 
 def sanitize_pattern(pattern: str) -> str:
+    if pattern == "^(https|s3)://([^/]+)/?(.*)$":
+        pattern = "^(https|s3)://(\\w+)$"
     pattern = pattern.replace("\\p{XDigit}", "[A-Fa-f0-9]")
     pattern = pattern.replace("\\p{P}", "[.,;]")
     pattern = pattern.replace("\\p{Punct}", "[.,;]")
@@ -138,6 +142,11 @@ def sanitize_pattern(pattern: str) -> str:
     pattern = pattern.replace("\\p{M}", "[`]")
     pattern = pattern.replace("\\p{IsLetter}", "[a-zA-Z]")
     pattern = pattern.replace("[:alnum:]", "[a-zA-Z0-9]")
+    pattern = pattern.replace("\\p{ASCII}*", "[a-zA-Z0-9]")
+    pattern = pattern.replace("\\p{Alnum}", "[a-zA-Z0-9]")
+
+    if "\\p{" in pattern:
+        LOG.warning("Find potential additional pattern that need to be sanitized: %s", pattern)
     return pattern
 
 
@@ -260,7 +269,7 @@ def _(shape: MapShape, graph: ShapeGraph) -> Dict[str, Instance]:
 
 def generate_arn(shape: StringShape):
     if not shape.metadata:
-        return "arn:aws:ec2:us-east-1:1234567890123:instance/i-abcde0123456789f"
+        return DEFAULT_ARN
 
     def _generate_arn():
         # some custom hacks
@@ -274,9 +283,10 @@ def generate_arn(shape: StringShape):
         if pattern:
             # FIXME: also conforming to length may be difficult
             pattern = sanitize_arn_pattern(pattern)
+            pattern = sanitize_pattern(pattern)
             arn = rstr.xeger(pattern)
         else:
-            arn = "arn:aws:ec2:us-east-1:1234567890123:instance/i-abcde0123456789f"
+            arn = DEFAULT_ARN
 
         # if there's a value set for the region, replace with a randomly picked region
         # TODO: splitting the ARNs here by ":" sometimes fails for some reason (e.g. or dynamodb for some reason)
@@ -317,9 +327,18 @@ def _(shape: StringShape, graph: ShapeGraph) -> str:
     if (
         shape.name.endswith("ARN")
         or shape.name.endswith("Arn")
+        or shape.name.endswith("ArnString")
         or shape.name == "AmazonResourceName"
     ):
-        return generate_arn(shape)
+        try:
+            return generate_arn(shape)
+        except re.error:
+            LOG.error(
+                "Could not generate arn pattern for %s, with pattern %s",
+                shape.name,
+                shape.metadata.get("pattern", "(no pattern set)"),
+            )
+            return DEFAULT_ARN
 
     max_len: int = shape.metadata.get("max") or 256
     min_len: int = shape.metadata.get("min") or 0
@@ -333,7 +352,10 @@ def _(shape: StringShape, graph: ShapeGraph) -> str:
             return random.choice(words)
         else:
             return "a" * str_len
-
+    if shape.name == "EndpointId" and pattern == "^[A-Za-z0-9\\-]+[\\.][A-Za-z0-9\\-]+$":
+        # there are sometimes issues with this pattern, because it could create invalid host labels, e.g. b6NOZqj5rIMdcta4IKyKRHvZakH90r.-wzuX6tQ-pB-pTNePY2
+        # for simplification we just remove the dash for now
+        pattern = "^[A-Za-z0-9]+[\\.][A-Za-z0-9]+$"
     pattern = sanitize_pattern(pattern)
 
     try:
@@ -347,6 +369,11 @@ def _(shape: StringShape, graph: ShapeGraph) -> str:
         return val[: min(max_len, len(val))]
     except re.error:
         # TODO: this will likely break the pattern
+        LOG.error(
+            "Could not generate pattern for %s, with pattern %s",
+            shape.name,
+            shape.metadata.get("pattern", "(no pattern set)"),
+        )
         return "0" * str_len
 
 
