@@ -521,7 +521,7 @@ def apply_json_patch_safe(subject, patch_operations, in_place=True, return_list=
                 if isinstance(target, list) and not path.endswith("/-"):
                     # if "path" is an attribute name pointing to an array in "subject", and we're running
                     # an "add" operation, then we should use the standard-compliant notation "/path/-"
-                    operation["path"] = "%s/-" % path
+                    operation["path"] = f"{path}/-"
 
             result = apply_patch(subject, [operation], in_place=in_place)
             if not in_place:
@@ -556,6 +556,7 @@ def import_api_from_openapi_spec(rest_api: RestAPI, body: Dict, query_params: Di
     # 1. validate the "mode" property of the spec document, "merge" or "overwrite"
     # 2. validate the document type, "swagger" or "openapi"
 
+    rest_api.version = resolved_schema.get("info", {}).get("version")
     # XXX for some reason this makes cf tests fail that's why is commented.
     # test_cfn_handle_serverless_api_resource
     # rest_api.name = resolved_schema.get("info", {}).get("title")
@@ -563,10 +564,12 @@ def import_api_from_openapi_spec(rest_api: RestAPI, body: Dict, query_params: Di
 
     # Remove default root, then add paths from API spec
     rest_api.resources = {}
-
+    rest_api.tags = {}
     # authorizers map to avoid duplication
     authorizers = {}
 
+    region_details = get_apigateway_store()
+
     def create_authorizer(path_payload: dict) -> Authorizer:
         if "security" not in path_payload:
             return None
@@ -574,8 +577,9 @@ def import_api_from_openapi_spec(rest_api: RestAPI, body: Dict, query_params: Di
         security_schemes = path_payload.get("security")
         for security_scheme in security_schemes:
             for security_scheme_name, _ in security_scheme.items():
-                if security_scheme_name in body.get("securityDefinitions", []):
-                    security_config = body.get("securityDefinitions", {}).get(security_scheme_name)
+                security_definitions = body.get("securityDefinitions") or {}
+                if security_scheme_name in security_definitions:
+                    security_config = security_definitions.get(security_scheme_name)
                     aws_apigateway_authorizer = security_config.get(
                         "x-amazon-apigateway-authorizer", {}
                     )
@@ -584,11 +588,12 @@ def import_api_from_openapi_spec(rest_api: RestAPI, body: Dict, query_params: Di
 
                     if authorizers.get(security_scheme_name):
                         return authorizers.get(security_scheme_name)
-                    authorizer = rest_api.create_authorizer(
-                        create_resource_id(),
+
+                    authorizer = Authorizer(
+                        authorizer_id=create_resource_id(),
                         name=security_scheme_name,
-                        authorizer_type=aws_apigateway_authorizer.get("type"),
-                        provider_arns=None,
+                        authorizer_type=aws_apigateway_authorizer.get("type", "").upper(),
+                        provider_arns=aws_apigateway_authorizer.get("providerARNs"),
                         auth_type=security_config.get("x-amazon-apigateway-authtype"),
                         authorizer_uri=aws_apigateway_authorizer.get("authorizerUri"),
                         authorizer_credentials=aws_apigateway_authorizer.get(
@@ -603,8 +608,11 @@ def import_api_from_openapi_spec(rest_api: RestAPI, body: Dict, query_params: Di
                         )
                         or 300,
                     )
-                    if authorizer:
-                        authorizers[security_scheme_name] = authorizer
+
+                    region_details.authorizers.setdefault(rest_api.id, []).append(
+                        authorizer.to_json()
+                    )
+                    authorizers[security_scheme_name] = authorizer
                     return authorizer
 
     def get_or_create_path(abs_path: str, base_path: str):
@@ -716,7 +724,7 @@ def import_api_from_openapi_spec(rest_api: RestAPI, body: Dict, query_params: Di
             )
 
     # determine base path
-    basepath_mode = (query_params.get("basepath") or ["prepend"])[0]
+    basepath_mode = query_params.get("basepath") or "prepend"
     base_path = ""
     if basepath_mode == "prepend":
         base_path = resolved_schema.get("basePath") or ""
@@ -727,6 +735,9 @@ def import_api_from_openapi_spec(rest_api: RestAPI, body: Dict, query_params: Di
     for path in resolved_schema.get("paths", {}):
         get_or_create_path(base_path + path, base_path=base_path)
 
+    # binary types
+    rest_api.binaryMediaTypes = resolved_schema.get("x-amazon-apigateway-binary-media-types", [])
+
     policy = resolved_schema.get("x-amazon-apigateway-policy")
     if policy:
         policy = json.dumps(policy) if isinstance(policy, dict) else str(policy)
@@ -764,7 +775,11 @@ def get_target_resource_method(invocation_context: ApiInvocationContext) -> Opti
         return None
     methods = resource.get("resourceMethods") or {}
     method_name = invocation_context.method.upper()
-    return methods.get(method_name) or methods.get("ANY")
+    return (
+        methods.get(method_name)
+        or methods.get("ANY")
+        or methods.get("X-AMAZON-APIGATEWAY-ANY-METHOD")
+    )
 
 
 def get_event_request_context(invocation_context: ApiInvocationContext):
@@ -927,7 +942,7 @@ class OpenApiExporter:
     exporters: Dict[str, TypeExporter]
 
     def __init__(self):
-        self.exporters = {"swagger": self._swagger_export, "oas3": self._oas3_export}
+        self.exporters = {"swagger": self._swagger_export, "oas30": self._oas30_export}
         self.export_formats = {"application/json": "to_dict", "application/yaml": "to_yaml"}
 
     def export_api(
@@ -970,7 +985,7 @@ class OpenApiExporter:
 
         return getattr(spec, self.export_formats.get(export_format))()
 
-    def _oas3_export(self, api_id: str, stage: str, export_format: str) -> str:
+    def _oas30_export(self, api_id: str, stage: str, export_format: str) -> str:
         """
         https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md
         """
