@@ -366,7 +366,7 @@ def invoke_rest_api_integration_backend(invocation_context: ApiInvocationContext
             headers["X-Amz-Target"] = target
 
             result = common.make_http_request(
-                url=config.service_url("kineses"), data=payload, headers=headers, method="POST"
+                url=config.service_url("kinesis"), data=payload, headers=headers, method="POST"
             )
 
             # apply response template
@@ -477,6 +477,13 @@ def invoke_rest_api_integration_backend(invocation_context: ApiInvocationContext
                 table.put_item(Item=event_data)
                 response = requests_response(event_data)
                 return response
+        if uri.startswith("arn:aws:apigateway:") and ".appsync-api:" in uri:
+            # arn:aws:apigateway:us-east-1:appsyncid.appsync-api:path/graphql
+            uri_parts = uri.split(":")
+            app_sync_id = uri_parts[-2].replace(".appsync-api", "")
+            url = urljoin(config.service_url("appsync"), f"graphql/{app_sync_id}")
+            result = common.make_http_request(url, method="POST", headers=headers, data=data)
+            return result
         else:
             raise Exception(
                 'API Gateway action uri "%s", integration type %s not yet implemented'
