@@ -1,7 +1,11 @@
+import io
 import json
 import logging
 from copy import deepcopy
-from typing import IO
+from typing import IO, Dict
+
+from moto.apigateway import models as apigw_models
+from moto.core.utils import camelcase_to_underscores
 
 from localstack.aws.api import RequestContext, ServiceRequest, handler
 from localstack.aws.api.apigateway import (
@@ -10,6 +14,7 @@ from localstack.aws.api.apigateway import (
     ApiKeys,
     Authorizer,
     Authorizers,
+    BadRequestException,
     BasePathMapping,
     BasePathMappings,
     Blob,
@@ -26,6 +31,7 @@ from localstack.aws.api.apigateway import (
     ListOfPatchOperation,
     ListOfString,
     MapOfStringToString,
+    MethodResponse,
     NotFoundException,
     NullableBoolean,
     NullableInteger,
@@ -33,6 +39,7 @@ from localstack.aws.api.apigateway import (
     RequestValidator,
     RequestValidators,
     RestApi,
+    RestApis,
     String,
     Tags,
     TestInvokeMethodRequest,
@@ -40,13 +47,14 @@ from localstack.aws.api.apigateway import (
     VpcLink,
     VpcLinks,
 )
-from localstack.aws.forwarder import create_aws_request_context
+from localstack.aws.forwarder import NotImplementedAvoidFallbackError, create_aws_request_context
 from localstack.constants import APPLICATION_JSON
 from localstack.services.apigateway.helpers import (
     OpenApiExporter,
     apply_json_patch_safe,
     find_api_subentity_by_id,
     get_apigateway_store,
+    import_api_from_openapi_spec,
 )
 from localstack.services.apigateway.invocations import invoke_rest_api_from_request
 from localstack.services.apigateway.patches import apply_patches
@@ -54,7 +62,12 @@ from localstack.services.apigateway.router_asf import ApigatewayRouter, to_invoc
 from localstack.services.edge import ROUTER
 from localstack.services.moto import call_moto
 from localstack.services.plugins import ServiceLifecycleHook
-from localstack.utils.collections import PaginatedList, ensure_list
+from localstack.utils.collections import (
+    DelSafeDict,
+    PaginatedList,
+    ensure_list,
+    select_from_typed_dict,
+)
 from localstack.utils.json import parse_json_or_yaml
 from localstack.utils.strings import short_uid, str_to_bool, to_str
 from localstack.utils.time import now_utc
@@ -72,6 +85,10 @@ class ApigatewayProvider(ApigatewayApi, ServiceLifecycleHook):
         apply_patches()
         self.router.register_routes()
 
+    @staticmethod
+    def _get_moto_backend(context: RequestContext) -> apigw_models.APIGatewayBackend:
+        return apigw_models.apigateway_backends[context.account_id][context.region]
+
     @handler("TestInvokeMethod", expand=False)
     def test_invoke_method(
         self, context: RequestContext, request: TestInvokeMethodRequest
@@ -102,14 +119,98 @@ class ApigatewayProvider(ApigatewayApi, ServiceLifecycleHook):
 
     @handler("CreateRestApi", expand=False)
     def create_rest_api(self, context: RequestContext, request: CreateRestApiRequest) -> RestApi:
+        if request.get("description") == "":
+            raise BadRequestException("Description cannot be an empty string")
         result = call_moto(context)
-        if not result.get("binaryMediaTypes"):
-            result.pop("binaryMediaTypes")
-        if not result.get("tags"):
-            result.pop("tags")
-        if result.get("version") == "V1":
-            result.pop("version")
-        return result
+        moto_backend = self._get_moto_backend(context)
+        rest_api = moto_backend.apis.get(result["id"])
+        rest_api.version = request.get("version")
+        response = rest_api.to_dict()
+        remove_empty_attributes_from_rest_api(response)
+
+        return response
+
+    def get_rest_api(self, context: RequestContext, rest_api_id: String) -> RestApi:
+        rest_api: RestApi = call_moto(context)
+        remove_empty_attributes_from_rest_api(rest_api)
+        return rest_api
+
+    def update_rest_api(
+        self,
+        context: RequestContext,
+        rest_api_id: String,
+        patch_operations: ListOfPatchOperation = None,
+    ) -> RestApi:
+        moto_backend = self._get_moto_backend(context)
+        rest_api = moto_backend.apis.get(rest_api_id)
+        if not rest_api:
+            raise NotFoundException(
+                f"Invalid API identifier specified {context.account_id}:{rest_api_id}"
+            )
+
+        fixed_patch_ops = []
+        binary_media_types_path = "/binaryMediaTypes"
+        for patch_op in patch_operations:
+            patch_op_path = patch_op.get("path", "")
+            # binaryMediaTypes has a specific way of being set
+            # see https://docs.aws.amazon.com/apigateway/latest/api/API_PatchOperation.html
+            # TODO: maybe implement a more generalized way if this happens anywhere else
+            if patch_op_path.startswith(binary_media_types_path):
+                if patch_op_path == binary_media_types_path:
+                    raise BadRequestException(f"Invalid patch path {patch_op_path}")
+                value = patch_op_path.rsplit("/", maxsplit=1)[-1]
+                path_value = value.replace("~1", "/")
+                patch_op["path"] = binary_media_types_path
+
+                if patch_op["op"] == "add":
+                    patch_op["value"] = path_value
+
+                elif patch_op["op"] == "remove":
+                    remove_index = rest_api.binaryMediaTypes.index(path_value)
+                    patch_op["path"] = f"{binary_media_types_path}/{remove_index}"
+
+                elif patch_op["op"] == "replace":
+                    # AWS is behaving weirdly, and will actually remove/add instead of replacing in place
+                    # it will put the replaced value last in the array
+                    replace_index = rest_api.binaryMediaTypes.index(path_value)
+                    fixed_patch_ops.append(
+                        {"op": "remove", "path": f"{binary_media_types_path}/{replace_index}"}
+                    )
+                    patch_op["op"] = "add"
+
+            fixed_patch_ops.append(patch_op)
+
+        if not isinstance(rest_api.__dict__, DelSafeDict):
+            rest_api.__dict__ = DelSafeDict(rest_api.__dict__)
+
+        _patch_api_gateway_entity(rest_api.__dict__, fixed_patch_ops)
+
+        # fix data types after patches have been applied
+        if rest_api.minimum_compression_size:
+            rest_api.minimum_compression_size = int(rest_api.minimum_compression_size or -1)
+        endpoint_configs = rest_api.endpoint_configuration or {}
+        if isinstance(endpoint_configs.get("vpcEndpointIds"), str):
+            endpoint_configs["vpcEndpointIds"] = [endpoint_configs["vpcEndpointIds"]]
+
+        response = rest_api.to_dict()
+        remove_empty_attributes_from_rest_api(response, remove_tags=False)
+        return response
+
+    @handler("PutRestApi", expand=False)
+    def put_rest_api(self, context: RequestContext, request: PutRestApiRequest) -> RestApi:
+        moto_backend = self._get_moto_backend(context)
+        rest_api = moto_backend.apis.get(request["restApiId"])
+        body_data = request["body"].read()
+
+        openapi_spec = parse_json_or_yaml(to_str(body_data))
+        rest_api = import_api_from_openapi_spec(
+            rest_api, openapi_spec, context.request.values.to_dict()
+        )
+
+        response = rest_api.to_dict()
+        remove_empty_attributes_from_rest_api(response)
+        # TODO: verify this
+        return to_rest_api_response_json(response)
 
     def delete_rest_api(self, context: RequestContext, rest_api_id: String) -> None:
         try:
@@ -120,6 +221,24 @@ class ApigatewayProvider(ApigatewayApi, ServiceLifecycleHook):
                 f"Invalid API identifier specified {context.account_id}:{rest_api_id}"
             ) from e
 
+    def get_rest_apis(
+        self, context: RequestContext, position: String = None, limit: NullableInteger = None
+    ) -> RestApis:
+        response: RestApis = call_moto(context)
+        for rest_api in response["items"]:
+            remove_empty_attributes_from_rest_api(rest_api)
+        return response
+
+    # method responses
+
+    @handler("UpdateMethodResponse", expand=False)
+    def update_method_response(
+        self, context: RequestContext, request: TestInvokeMethodRequest
+    ) -> MethodResponse:
+        # this operation is not implemented by moto, but raises a 500 error (instead of a 501).
+        # avoid a fallback to moto and return the 501 to the client directly instead.
+        raise NotImplementedAvoidFallbackError
+
     # authorizers
 
     @handler("CreateAuthorizer", expand=False)
@@ -635,25 +754,32 @@ class ApigatewayProvider(ApigatewayApi, ServiceLifecycleHook):
         fail_on_warnings: Boolean = None,
         parameters: MapOfStringToString = None,
     ) -> RestApi:
+
         body_data = body.read()
 
+        # create rest api
         openapi_spec = parse_json_or_yaml(to_str(body_data))
-        response = _call_moto(
+        create_api_request = CreateRestApiRequest(name=openapi_spec.get("info").get("title"))
+        create_api_context = create_custom_context(
             context,
             "CreateRestApi",
-            CreateRestApiRequest(name=openapi_spec.get("info").get("title")),
+            create_api_request,
         )
+        response = self.create_rest_api(create_api_context, create_api_request)
 
-        return _call_moto(
+        # put rest api
+        put_api_request = PutRestApiRequest(
+            restApiId=response.get("id"),
+            failOnWarnings=str_to_bool(fail_on_warnings) or False,
+            parameters=parameters or {},
+            body=io.BytesIO(body_data),
+        )
+        put_api_context = create_custom_context(
             context,
             "PutRestApi",
-            PutRestApiRequest(
-                restApiId=response.get("id"),
-                failOnWarnings=str_to_bool(fail_on_warnings) or False,
-                parameters=parameters or {},
-                body=body_data,
-            ),
+            put_api_request,
         )
+        return self.put_rest_api(put_api_context, put_api_request)
 
     def delete_integration(
         self, context: RequestContext, rest_api_id: String, resource_id: String, http_method: String
@@ -718,22 +844,35 @@ class ApigatewayProvider(ApigatewayApi, ServiceLifecycleHook):
 # ---------------
 
 
-def _call_moto(context: RequestContext, operation_name: str, parameters: ServiceRequest):
-    """
-    Not necessarily the pattern we want to follow in the future, but this makes possible to nest
-    moto call and still be interface compatible.
+def remove_empty_attributes_from_rest_api(rest_api: RestApi, remove_tags=True):
+    if not rest_api.get("binaryMediaTypes"):
+        rest_api.pop("binaryMediaTypes", None)
 
-    Ripped :call_moto_with_request: from moto.py but applicable to any operation (operation_name).
-    """
-    local_context = create_aws_request_context(
+    if not rest_api.get("tags"):
+        if remove_tags:
+            rest_api.pop("tags", None)
+        else:
+            # if `tags` is falsy, set it to an empty dict
+            rest_api["tags"] = {}
+
+    if not rest_api.get("version"):
+        rest_api.pop("version", None)
+    if not rest_api.get("description"):
+        rest_api.pop("description", None)
+
+
+def create_custom_context(
+    context: RequestContext, action: str, parameters: ServiceRequest
+) -> RequestContext:
+    ctx = create_aws_request_context(
         service_name=context.service.service_name,
-        action=operation_name,
+        action=action,
         parameters=parameters,
         region=context.region,
     )
-
-    local_context.request.headers.update(context.request.headers)
-    return call_moto(local_context)
+    ctx.request.headers.update(context.request.headers)
+    ctx.account_id = context.account_id
+    return ctx
 
 
 def normalize_authorizer(data):
@@ -747,33 +886,68 @@ def normalize_authorizer(data):
     return entries if is_list else entries[0]
 
 
+def _patch_api_gateway_entity(entity: Dict, patch_operations: ListOfPatchOperation):
+    not_supported_attributes = {"/id", "/region_name", "/create_date"}
+
+    model_attributes = list(entity.keys())
+    for operation in patch_operations:
+        path_start = operation["path"].strip("/").split("/")[0]
+        path_start_usc = camelcase_to_underscores(path_start)
+        if path_start not in model_attributes and path_start_usc in model_attributes:
+            operation["path"] = operation["path"].replace(path_start, path_start_usc)
+        if operation["path"] in not_supported_attributes:
+            raise BadRequestException(f"Invalid patch path {operation['path']}")
+
+    apply_json_patch_safe(entity, patch_operations, in_place=True)
+
+
 def to_authorizer_response_json(api_id, data):
-    return to_response_json("authorizer", data, api_id=api_id)
+    result = to_response_json("authorizer", data, api_id=api_id)
+    result = select_from_typed_dict(Authorizer, result)
+    return result
 
 
 def to_validator_response_json(api_id, data):
-    return to_response_json("validator", data, api_id=api_id)
+    result = to_response_json("validator", data, api_id=api_id)
+    result = select_from_typed_dict(RequestValidator, result)
+    return result
 
 
 def to_documentation_part_response_json(api_id, data):
-    return to_response_json("documentationpart", data, api_id=api_id)
+    result = to_response_json("documentationpart", data, api_id=api_id)
+    result = select_from_typed_dict(DocumentationPart, result)
+    return result
 
 
 def to_base_mapping_response_json(domain_name, base_path, data):
     self_link = "/domainnames/%s/basepathmappings/%s" % (domain_name, base_path)
-    return to_response_json("basepathmapping", data, self_link=self_link)
+    result = to_response_json("basepathmapping", data, self_link=self_link)
+    result = select_from_typed_dict(BasePathMapping, result)
+    return result
 
 
 def to_account_response_json(data):
-    return to_response_json("account", data, self_link="/account")
+    result = to_response_json("account", data, self_link="/account")
+    result = select_from_typed_dict(Account, result)
+    return result
 
 
 def to_vpc_link_response_json(data):
-    return to_response_json("vpclink", data)
+    result = to_response_json("vpclink", data)
+    result = select_from_typed_dict(VpcLink, result)
+    return result
 
 
 def to_client_cert_response_json(data):
-    return to_response_json("clientcertificate", data, id_attr="clientCertificateId")
+    result = to_response_json("clientcertificate", data, id_attr="clientCertificateId")
+    result = select_from_typed_dict(ClientCertificate, result)
+    return result
+
+
+def to_rest_api_response_json(data):
+    result = to_response_json("restapi", data)
+    result = select_from_typed_dict(RestApi, result)
+    return result
 
 
 def to_response_json(model_type, data, api_id=None, self_link=None, id_attr=None):
@@ -785,6 +959,9 @@ def to_response_json(model_type, data, api_id=None, self_link=None, id_attr=None
         self_link = "/%ss/%s" % (model_type, data[id_attr])
         if api_id:
             self_link = "/restapis/%s/%s" % (api_id, self_link)
+    # TODO: check if this is still required - "_links" are listed in the sample responses in the docs, but
+    #  recent parity tests indicate that this field is not returned by real AWS...
+    # https://docs.aws.amazon.com/apigateway/latest/api/API_GetAuthorizers.html#API_GetAuthorizers_Example_1_Response
     if "_links" not in result:
         result["_links"] = {}
     result["_links"]["self"] = {"href": self_link}
