@@ -10,7 +10,6 @@ from localstack.constants import APPLICATION_JSON
 from localstack.services.apigateway.context import ApiInvocationContext
 from localstack.utils.aws.templating import VelocityUtil, VtlTemplate
 from localstack.utils.json import extract_jsonpath, json_safe
-from localstack.utils.numbers import is_number, to_number
 from localstack.utils.strings import to_str
 
 LOG = logging.getLogger(__name__)
@@ -62,7 +61,7 @@ class VelocityUtilApiGateway(VelocityUtil):
     """
     Simple class to mimic the behavior of variable '$util' in AWS API Gateway integration
     velocity templates.
-    See: http://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-mapping-template-reference.html
+    See: https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-mapping-template-reference.html
     """
 
     def base64Encode(self, s):
@@ -86,17 +85,22 @@ class VelocityUtilApiGateway(VelocityUtil):
     def urlDecode(self, s):
         return unquote_plus(s)
 
-    def escapeJavaScript(self, s):
-        try:
-            return json.dumps(json.loads(s))
-        except Exception:
-            primitive_types = (str, int, bool, float, type(None))
-            s = s if isinstance(s, primitive_types) else str(s)
-        if str(s).strip() in {"true", "false"}:
-            s = bool(s)
-        elif s not in [True, False] and is_number(s):
-            s = to_number(s)
-        return json.dumps(s)
+    def escapeJavaScript(self, obj: Any) -> str:
+        """
+        Converts the given object to a string and escapes any regular single quotes (') into escaped ones (\').
+        JSON dumps will escape the single quotes.
+        https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-mapping-template-reference.html
+        """
+        if obj is None:
+            return "null"
+        if isinstance(obj, str):
+            # empty string escapes to empty object
+            if len(obj.strip()) == 0:
+                return "{}"
+            return json.dumps(obj)[1:-1]
+        if obj in (True, False):
+            return str(obj).lower()
+        return str(obj)
 
 
 class VelocityInput:
@@ -181,7 +185,10 @@ class Templates:
                 "params": {
                     "path": api_context.path_params,
                     "querystring": api_context.query_params(),
-                    "header": api_context.headers,
+                    # Sometimes we get a werkzeug.datastructures.Headers object, sometimes a dict
+                    # depending on the request. We need to convert to a dict to be able to render
+                    # the template.
+                    "header": dict(api_context.headers),
                 },
             },
         }
@@ -209,7 +216,9 @@ class RequestTemplates(Templates):
 
 class ResponseTemplates(Templates):
     """
-    Handles response template rendering
+    Handles response template rendering. The integration response status code is used to select
+    the correct template to render, if there is no template for the status code, the default
+    template is used.
     """
 
     def render(self, api_context: ApiInvocationContext, **kwargs) -> Union[bytes, str]:
@@ -223,21 +232,42 @@ class ResponseTemplates(Templates):
         # depending on the type of templates.
         api_context.data = response._content
 
-        integration_responses = integration.get("integrationResponses") or {}
+        # status code returned by the integration
+        status_code = str(response.status_code)
+
+        # get the integration responses configuration from the integration object
+        integration_responses = integration.get("integrationResponses")
         if not integration_responses:
             return response._content
-        entries = list(integration_responses.keys())
-        return_code = str(response.status_code)
-        if return_code not in entries and len(entries) > 1:
-            LOG.info("Found multiple integration response status codes: %s", entries)
-            return response._content
-        return_code = entries[0]
 
-        response_templates = integration_responses[return_code].get("responseTemplates", {})
+        # get the configured integration response status codes,
+        # e.g. ["200", "400", "500"]
+        integration_status_codes = [str(code) for code in list(integration_responses.keys())]
+
+        # we return the response as is if the integration response status code is not on
+        # the list of configured integration response status codes
+        if status_code not in integration_status_codes or not integration_status_codes:
+            return response._content
+
+        # if there is integration response for the status code returned
+        # by the integration we use the template configured for that status code
+        if status_code in integration_responses:
+            response_templates = integration_responses[status_code].get("responseTemplates", {})
+        else:
+            # if there is no integration response for the status code returned
+            # by the integration we use the first integration response status code
+            LOG.info(
+                f"Found multiple integration response status codes: {integration_status_codes}"
+            )
+            response_templates = integration_responses[0].get("responseTemplates", {})
+
+        # we only support JSON templates for now - if there is no template we return
+        # the response as is
         template = response_templates.get(APPLICATION_JSON, {})
         if not template:
             return response._content
 
+        # we render the template with the context data and the response content
         variables = self.build_variables_mapping(api_context)
         response._content = self.render_vtl(template, variables=variables)
         LOG.info("Endpoint response body after transformations:\n%s", response._content)
