@@ -92,6 +92,7 @@ class Invocation:
     invoked_arn: str
     client_context: Optional[str]
     invocation_type: InvocationType
+    invoke_time: datetime
 
 
 class ArchiveCode(metaclass=ABCMeta):
@@ -432,8 +433,7 @@ class ResourcePolicy:
 
 @dataclasses.dataclass
 class FunctionResourcePolicy:
-    revision_id: str
-    policy: ResourcePolicy  # TODO: do we have a typed IAM policy somewhere already?
+    policy: ResourcePolicy
 
 
 @dataclasses.dataclass
@@ -629,7 +629,7 @@ class Function:
     versions: dict[str, FunctionVersion] = dataclasses.field(default_factory=dict)
     function_url_configs: dict[str, FunctionUrlConfig] = dataclasses.field(
         default_factory=dict
-    )  # key has to be $LATEST or alias name
+    )  # key is $LATEST, version, or alias
     permissions: dict[str, FunctionResourcePolicy] = dataclasses.field(
         default_factory=dict
     )  # key is $LATEST, version or alias
