@@ -6,6 +6,7 @@ import logging
 import random
 import uuid
 from concurrent.futures import Executor, Future, ThreadPoolExecutor
+from datetime import datetime
 from hashlib import sha256
 from pathlib import PurePosixPath, PureWindowsPath
 from threading import RLock
@@ -233,6 +234,7 @@ class LambdaService:
                 invoked_arn=invoked_arn,
                 client_context=client_context,
                 invocation_type=invocation_type,
+                invoke_time=datetime.now(),
             )
         )
 
@@ -291,6 +293,8 @@ class LambdaService:
                 return
 
         # TODO is it necessary to get the version again? Should be locked for modification anyway
+        # Without updating the new state, the function would not change to active, last_update would be missing, and
+        # the revision id would not be updated.
         state = lambda_stores[function_version.id.account][function_version.id.region]
         function = state.functions[function_version.id.function_name]
         current_version = function.versions[function_version.id.qualifier]
