@@ -4,7 +4,9 @@ from moto.awslambda import models as moto_awslambda_models
 
 from localstack import config
 from localstack.services.awslambda.lambda_api import handle_lambda_url_invocation
+from localstack.services.awslambda.lambda_utils import get_default_executor_mode
 from localstack.services.edge import ROUTER
+from localstack.utils.analytics import log
 from localstack.utils.aws import arns, aws_stack
 from localstack.utils.aws.request_context import AWS_REGION_REGEX
 from localstack.utils.patch import patch
@@ -34,6 +36,13 @@ def start_lambda(port=None, asynchronous=False):
         endpoint=handle_lambda_url_invocation,
     )
 
+    log.event(
+        "lambda:config",
+        version="v1",
+        executor_mode=config.LAMBDA_EXECUTOR,
+        default_executor_mode=get_default_executor_mode(),
+    )
+
     # print a warning if we're not running in Docker but using Docker based LAMBDA_EXECUTOR
     if "docker" in lambda_utils.get_executor_mode() and not config.is_in_docker and not is_linux():
         LOG.warning(
