@@ -19,7 +19,7 @@ class GatewayResponse(GenericBaseModel):
 
     def fetch_state(self, stack_name, resources):
         props = self.props
-        api_id = self.resolve_refs_recursively(stack_name, props["RestApiId"], resources)
+        api_id = props.get("RestApiId")
         if not api_id:
             return
         client = aws_stack.connect_to_service("apigateway")
@@ -53,8 +53,8 @@ class GatewayRequestValidator(GenericBaseModel):
     def fetch_state(self, stack_name, resources):
         client = aws_stack.connect_to_service("apigateway")
         props = self.props
-        api_id = self.resolve_refs_recursively(stack_name, props["RestApiId"], resources)
-        name = self.resolve_refs_recursively(stack_name, props["Name"], resources)
+        api_id = props["RestApiId"]
+        name = props["Name"]
         result = client.get_request_validators(restApiId=api_id).get("items", [])
         result = [r for r in result if r.get("name") == name]
         return result[0] if result else None
@@ -193,7 +193,6 @@ class GatewayDeployment(GenericBaseModel):
 
     def fetch_state(self, stack_name, resources):
         api_id = self.props.get("RestApiId")
-        api_id = self.resolve_refs_recursively(stack_name, api_id, resources)
 
         if not api_id:
             return None
@@ -232,9 +231,8 @@ class GatewayResource(GenericBaseModel):
 
     def fetch_state(self, stack_name, resources):
         props = self.props
-        api_id = props.get("RestApiId") or self.resource_id
-        api_id = self.resolve_refs_recursively(stack_name, api_id, resources)
-        parent_id = self.resolve_refs_recursively(stack_name, props.get("ParentId"), resources)
+        api_id = props.get("RestApiId") or self.logical_resource_id
+        parent_id = props.get("ParentId")
 
         if not api_id or not parent_id:
             return None
@@ -295,8 +293,8 @@ class GatewayMethod(GenericBaseModel):
     def fetch_state(self, stack_name, resources):
         props = self.props
 
-        api_id = self.resolve_refs_recursively(stack_name, props["RestApiId"], resources)
-        res_id = self.resolve_refs_recursively(stack_name, props["ResourceId"], resources)
+        api_id = props["RestApiId"]
+        res_id = props["ResourceId"]
         if not api_id or not res_id:
             return None
 
@@ -369,18 +367,12 @@ class GatewayMethod(GenericBaseModel):
 
             integration = props.get("Integration")
             if integration:
-                api_id = resource.resolve_refs_recursively(
-                    stack_name, props["RestApiId"], resources
-                )
-                res_id = resource.resolve_refs_recursively(
-                    stack_name, props["ResourceId"], resources
-                )
+                api_id = props["RestApiId"]
+                res_id = props["ResourceId"]
 
                 kwargs = keys_to_lower(integration)
                 if integration.get("Uri"):
-                    uri = resource.resolve_refs_recursively(
-                        stack_name, integration.get("Uri"), resources
-                    )
+                    uri = integration.get("Uri")
 
                     # Moto has a validate method on Uri for integration_type "HTTP" | "HTTP_PROXY" that does not accept
                     # Uri value without path, we need to add path ("/") if not exists
@@ -415,12 +407,8 @@ class GatewayMethod(GenericBaseModel):
 
             responses = props.get("MethodResponses") or []
             for response in responses:
-                api_id = resource.resolve_refs_recursively(
-                    stack_name, props["RestApiId"], resources
-                )
-                res_id = resource.resolve_refs_recursively(
-                    stack_name, props["ResourceId"], resources
-                )
+                api_id = props["RestApiId"]
+                res_id = props["ResourceId"]
                 apigateway.put_method_response(
                     restApiId=api_id,
                     resourceId=res_id,
@@ -458,8 +446,7 @@ class GatewayStage(GenericBaseModel):
         return "AWS::ApiGateway::Stage"
 
     def fetch_state(self, stack_name, resources):
-        api_id = self.props.get("RestApiId") or self.resource_id
-        api_id = self.resolve_refs_recursively(stack_name, api_id, resources)
+        api_id = self.props.get("RestApiId") or self.logical_resource_id
         if not api_id:
             return None
         result = aws_stack.connect_to_service("apigateway").get_stage(
@@ -508,7 +495,6 @@ class GatewayUsagePlan(GenericBaseModel):
 
     def fetch_state(self, stack_name, resources):
         plan_name = self.props.get("UsagePlanName")
-        plan_name = self.resolve_refs_recursively(stack_name, plan_name, resources)
         result = aws_stack.connect_to_service("apigateway").get_usage_plans().get("items", [])
         result = [r for r in result if r["name"] == plan_name]
         return (result or [None])[0]
@@ -556,9 +542,6 @@ class GatewayUsagePlan(GenericBaseModel):
             "Tags",
         ]
         update_config_props = select_attributes(props, parameters_to_select)
-        update_config_props = self.resolve_refs_recursively(
-            stack_name, update_config_props, resources
-        )
 
         if "Tags" in update_config_props:
             tags_dict = {}
@@ -618,7 +601,7 @@ class GatewayApiKey(GenericBaseModel):
 
     def fetch_state(self, stack_name, resources):
         props = self.props
-        key_name = self.resolve_refs_recursively(stack_name, props.get("Name"), resources)
+        key_name = props.get("Name")
         cust_id = props.get("CustomerId")
         result = aws_stack.connect_to_service("apigateway").get_api_keys().get("items", [])
         result = [
@@ -665,11 +648,9 @@ class GatewayUsagePlanKey(GenericBaseModel):
 
     def fetch_state(self, stack_name, resources):
         client = aws_stack.connect_to_service("apigateway")
-        key_id = self.resolve_refs_recursively(stack_name, self.props.get("KeyId"), resources)
-        key_type = self.resolve_refs_recursively(stack_name, self.props.get("KeyType"), resources)
-        plan_id = self.resolve_refs_recursively(
-            stack_name, self.props.get("UsagePlanId"), resources
-        )
+        key_id = self.props.get("KeyId")
+        key_type = self.props.get("KeyType")
+        plan_id = self.props.get("UsagePlanId")
         result = client.get_usage_plan_keys(usagePlanId=plan_id).get("items", [])
         result = [r for r in result if r["id"] == key_id and key_type in [None, r.get("type")]]
         return (result or [None])[0]
@@ -772,13 +753,13 @@ class GatewayModel(GenericBaseModel):
 
     def fetch_state(self, stack_name, resources):
         client = aws_stack.connect_to_service("apigateway")
-        api_id = self.resolve_refs_recursively(stack_name, self.props["RestApiId"], resources)
+        api_id = self.props["RestApiId"]
 
         items = client.get_models(restApiId=api_id)["items"]
         if not items:
             return None
 
-        model_name = self.resolve_refs_recursively(stack_name, self.props["Name"], resources)
+        model_name = self.props["Name"]
         models = [item for item in items if item["name"] == model_name]
         if models:
             return models[0]
