@@ -22,6 +22,7 @@ from localstack.utils.common import (
     select_attributes,
     to_bytes,
 )
+from localstack.utils.strings import short_uid
 from localstack.utils.testutil import create_zip_file
 
 
@@ -31,7 +32,7 @@ class LambdaFunction(GenericBaseModel):
         return "AWS::Lambda::Function"
 
     def fetch_state(self, stack_name, resources):
-        func_name = self.resolve_refs_recursively(stack_name, self.props["FunctionName"], resources)
+        func_name = self.props["FunctionName"]
         return aws_stack.connect_to_service("lambda").get_function(FunctionName=func_name)
 
     def get_physical_resource_id(self, attribute=None, **kwargs):
@@ -58,9 +59,6 @@ class LambdaFunction(GenericBaseModel):
             "VpcConfig",
         ]
         update_config_props = select_attributes(props, config_keys)
-        update_config_props = self.resolve_refs_recursively(
-            stack_name, update_config_props, resources
-        )
         if "Timeout" in update_config_props:
             update_config_props["Timeout"] = int(update_config_props["Timeout"])
         if "Code" in props:
@@ -204,8 +202,7 @@ class LambdaEventSourceMapping(GenericBaseModel):
         props = self.props
         source_arn = props.get("EventSourceArn")
         self_managed_src = props.get("SelfManagedEventSource")
-        function_name = self.resolve_refs_recursively(stack_name, props["FunctionName"], resources)
-        source_arn = self.resolve_refs_recursively(stack_name, source_arn, resources)
+        function_name = props["FunctionName"]
         if not function_name or (not source_arn and not self_managed_src):
             raise Exception("ResourceNotFound")
 
@@ -247,7 +244,7 @@ class LambdaPermission(GenericBaseModel):
 
     def fetch_state(self, stack_name, resources):
         props = self.props
-        func_name = self.resolve_refs_recursively(stack_name, props.get("FunctionName"), resources)
+        func_name = props.get("FunctionName")
         lambda_client = aws_stack.connect_to_service("lambda")
         return lambda_client.get_policy(FunctionName=func_name)
 
@@ -259,9 +256,6 @@ class LambdaPermission(GenericBaseModel):
         props = new_resource["Properties"]
         parameters_to_select = ["FunctionName", "Action", "Principal", "SourceArn"]
         update_config_props = select_attributes(props, parameters_to_select)
-        update_config_props = self.resolve_refs_recursively(
-            stack_name, update_config_props, resources
-        )
 
         client = aws_stack.connect_to_service("lambda")
         sid = new_resource["PhysicalResourceId"]
@@ -465,3 +459,72 @@ class LambdaCodeSigningConfig(GenericBaseModel):
                 },
             },
         }
+
+
+# TODO: test
+class LambdaLayerVersion(GenericBaseModel):
+    @staticmethod
+    def cloudformation_type():
+        return "AWS::Lambda::LayerVersion"
+
+    def get_physical_resource_id(self, attribute=None, **kwargs):
+        return self.state.get("LayerVersionArn")
+
+    def fetch_state(self, stack_name, resources):
+        layer_name = self.props.get("LayerName")
+        # TODO extract region name if layer_name is an ARN
+        client = aws_stack.connect_to_service("lambda")
+        layers = client.list_layer_versions(LayerName=layer_name).get("LayerVersions", [])
+        return layers[-1] if layers else None
+
+    @staticmethod
+    def add_defaults(resource, stack_name: str):
+        resource["Properties"]["LayerName"] = (
+            resource["Properties"].get("LayerName") or f"layer-{short_uid()}"
+        )
+
+    @staticmethod
+    def get_deploy_templates():
+        return {"create": {"function": "publish_layer_version"}}
+
+
+# TODO: test
+# TODO: remove inheritance
+class LambdaLayerVersionPermission(LambdaPermission):
+    @staticmethod
+    def cloudformation_type():
+        return "AWS::Lambda::LayerVersionPermission"
+
+    def fetch_state(self, stack_name, resources):
+        props = self.props
+        props["LayerVersionArn"] = props["LayerVersionArn"]
+        layer_name, version_number = self.layer_name_and_version(props)
+        layer_arn = arns.lambda_layer_arn(layer_name)
+        layer_arn_qualified = "%s:%s" % (layer_arn, version_number)
+        result = self.do_fetch_state(layer_name, layer_arn_qualified)
+        return result
+
+    @staticmethod
+    def layer_name_and_version(params):
+        layer_arn = params.get("LayerVersionArn", "")
+        parts = layer_arn.split(":")
+        layer_name = parts[6] if ":" in layer_arn else layer_arn
+        version_number = int(parts[7] if len(parts) > 7 else 1)  # TODO fetch latest version number
+        return layer_name, version_number
+
+    @classmethod
+    def get_deploy_templates(cls):
+        def layer_permission_params(params, **kwargs):
+            layer_name, version_number = cls.layer_name_and_version(params)
+            result = select_attributes(params, ["Action", "Principal"])
+            result["StatementId"] = short_uid()
+            result["LayerName"] = layer_name
+            result["VersionNumber"] = version_number
+            return result
+
+        return {
+            "create": {
+                "function": "add_layer_version_permission",
+                "parameters": layer_permission_params,
+            }
+        }
