@@ -73,8 +73,7 @@ class DynamoDBTable(GenericBaseModel):
         return self.props.get("TableName")
 
     def fetch_state(self, stack_name, resources):
-        table_name = self.props.get("TableName") or self.resource_id
-        table_name = self.resolve_refs_recursively(stack_name, table_name, resources)
+        table_name = self.props.get("TableName") or self.logical_resource_id
         return aws_stack.connect_to_service("dynamodb").describe_table(TableName=table_name)
 
     @staticmethod
