@@ -35,13 +35,12 @@ class ElasticsearchDomain(GenericBaseModel):
 
     def fetch_state(self, stack_name, resources):
         domain_name = self._domain_name()
-        domain_name = self.resolve_refs_recursively(stack_name, domain_name, resources)
         return aws_stack.connect_to_service("es").describe_elasticsearch_domain(
             DomainName=domain_name
         )
 
     def _domain_name(self):
-        return self.props.get("DomainName") or self.resource_id
+        return self.props.get("DomainName") or self.logical_resource_id
 
     @staticmethod
     def get_deploy_templates():
