@@ -8,7 +8,6 @@ from botocore.exceptions import ClientError
 from localstack.services.awslambda.lambda_api import IAM_POLICY_VERSION
 from localstack.services.cloudformation.deployment_utils import (
     PLACEHOLDER_AWS_NO_VALUE,
-    PLACEHOLDER_RESOURCE_NAME,
     dump_json_params,
     generate_default_name,
     param_defaults,
@@ -49,7 +48,6 @@ class IAMManagedPolicy(GenericBaseModel):
             iam = aws_stack.connect_to_service("iam")
             resource = resources[resource_id]
             props = resource["Properties"]
-            cls.resolve_refs_recursively(stack_name, props, resources)
 
             policy_doc = json.dumps(remove_none_values(props["PolicyDocument"]))
             policy = iam.create_policy(
@@ -75,22 +73,10 @@ class IAMUser(GenericBaseModel):
     def get_physical_resource_id(self, attribute=None, **kwargs):
         return self.props.get("UserName")
 
-    def get_resource_name(self):
-        return self.props.get("UserName")
-
     def fetch_state(self, stack_name, resources):
-        user_name = self.resolve_refs_recursively(stack_name, self.props.get("UserName"), resources)
+        user_name = self.props.get("UserName")
         return aws_stack.connect_to_service("iam").get_user(UserName=user_name)["User"]
 
-    def update_resource(self, new_resource, stack_name, resources):
-        props = new_resource["Properties"]
-        client = aws_stack.connect_to_service("iam")
-        return client.update_user(
-            UserName=props.get("UserName"),
-            NewPath=props.get("NewPath") or "",
-            NewUserName=props.get("NewUserName") or "",
-        )
-
     @staticmethod
     def add_defaults(resource, stack_name: str):
         role_name = resource["Properties"].get("UserName")
@@ -175,12 +161,14 @@ class IAMAccessKey(GenericBaseModel):
         return "AWS::IAM::AccessKey"
 
     def get_physical_resource_id(self, attribute=None, **kwargs):
-        if attribute == "SecretAccessKey":
-            return self.props("SecretAccessKey")
         return self.physical_resource_id
 
+    def get_cfn_attribute(self, attribute_name):
+        if attribute_name == "SecretAccessKey":
+            return self.props("SecretAccessKey")
+
     def fetch_state(self, stack_name, resources):
-        user_name = self.resolve_refs_recursively(stack_name, self.props.get("UserName"), resources)
+        user_name = self.props.get("UserName")
         access_key_id = self.get_physical_resource_id()
         if access_key_id:
             keys = aws_stack.connect_to_service("iam").list_access_keys(UserName=user_name)[
@@ -188,6 +176,16 @@ class IAMAccessKey(GenericBaseModel):
             ]
             return [key for key in keys if key["AccessKeyId"] == access_key_id][0]
 
+    def update_resource(self, new_resource, stack_name, resources):
+        access_key_id = self.get_physical_resource_id()
+        new_props = new_resource["Properties"]
+        user_name = new_props.get("UserName")
+        status = new_props.get("Status")
+
+        aws_stack.connect_to_service("iam").update_access_key(
+            UserName=user_name, AccessKeyId=access_key_id, Status=status
+        )
+
     @staticmethod
     def get_deploy_templates():
         def _delete(resource_id, resources, resource_type, func, stack_name):
@@ -204,15 +202,23 @@ class IAMAccessKey(GenericBaseModel):
                     raise
 
         def _store_key_id(result, resource_id, resources, resource_type):
-            resources[resource_id]["PhysicalResourceId"] = result["AccessKey"]["AccessKeyId"]
+            access_key_id = result["AccessKey"]["AccessKeyId"]
+            resources[resource_id]["PhysicalResourceId"] = access_key_id
             resources[resource_id]["Properties"]["SecretAccessKey"] = result["AccessKey"][
                 "SecretAccessKey"
             ]
+            status = resources[resource_id]["Properties"].get("Status", "Active")
+            if status == "Inactive":
+                user_name = resources[resource_id]["Properties"]["UserName"]
+                client = aws_stack.connect_to_service("iam")
+                client.update_access_key(
+                    UserName=user_name, AccessKeyId=access_key_id, Status="Inactive"
+                )
 
         return {
             "create": {
                 "function": "create_access_key",
-                "parameters": ["UserName", "Serial", "Status"],
+                "parameters": ["UserName"],
                 "result_handler": _store_key_id,
             },
             "delete": {"function": _delete},
@@ -224,9 +230,6 @@ class IAMRole(GenericBaseModel):
     def cloudformation_type():
         return "AWS::IAM::Role"
 
-    def get_resource_name(self):
-        return self.props.get("RoleName")
-
     def get_physical_resource_id(self, attribute=None, **kwargs):
         role_name = self.properties.get("RoleName")
         if not role_name:
@@ -236,7 +239,7 @@ class IAMRole(GenericBaseModel):
         return role_name
 
     def fetch_state(self, stack_name, resources):
-        role_name = self.resolve_refs_recursively(stack_name, self.props.get("RoleName"), resources)
+        role_name = self.props.get("RoleName")
         client = aws_stack.connect_to_service("iam")
         return client.get_role(RoleName=role_name)["Role"]
 
@@ -256,13 +259,13 @@ class IAMRole(GenericBaseModel):
                 dummy_resources = {
                     resource_id: {"Properties": {"RoleName": _states.get("RoleName")}}
                 }
-                self._pre_delete(resource_id, dummy_resources, None, None, None)
+                IAMRole._pre_delete(resource_id, dummy_resources, None, None, None)
                 client.delete_role(RoleName=_states.get("RoleName"))
                 role = client.create_role(
                     RoleName=props.get("RoleName"),
                     AssumeRolePolicyDocument=str(props_policy),
                 )
-                self._post_create(resource_id, resources, None, None, None)
+                IAMRole._post_create(resource_id, resources, None, None, None)
                 return role["Role"]
 
         return client.update_role(
@@ -277,13 +280,9 @@ class IAMRole(GenericBaseModel):
                 stack_name, resource["LogicalResourceId"]
             )
 
-    @staticmethod
-    def _post_create(resource_id, resources, resource_type, func, stack_name):
+    @classmethod
+    def _post_create(cls, resource_id, resources, resource_type, func, stack_name):
         """attaches managed policies from the template to the role"""
-        from localstack.utils.cloudformation.template_deployer import (
-            find_stack,
-            resolve_refs_recursively,
-        )
 
         iam = aws_stack.connect_to_service("iam")
         resource = resources[resource_id]
@@ -295,9 +294,6 @@ class IAMRole(GenericBaseModel):
         for arn in policy_arns:
             iam.attach_role_policy(RoleName=role_name, PolicyArn=arn)
 
-        # TODO: to be removed once we change the method signature to pass in the stack object directly!
-        stack = find_stack(stack_name)
-
         # add inline policies
         inline_policies = props.get("Policies", [])
         for policy in inline_policies:
@@ -316,7 +312,6 @@ class IAMRole(GenericBaseModel):
             # get policy document - make sure we're resolving references in the policy doc
             doc = dict(policy["PolicyDocument"])
             doc = remove_none_values(doc)
-            doc = resolve_refs_recursively(stack, doc)
 
             doc["Version"] = doc.get("Version") or IAM_POLICY_VERSION
             statements = ensure_list(doc["Statement"])
@@ -391,7 +386,7 @@ class IAMRole(GenericBaseModel):
                             ),
                             "AssumeRolePolicyDocument",
                         ),
-                        {"RoleName": PLACEHOLDER_RESOURCE_NAME},
+                        {"RoleName": "RoleName"},
                     ),
                 },
                 {"function": IAMRole._post_create},
@@ -410,9 +405,7 @@ class IAMServiceLinkedRole(GenericBaseModel):
 
     def fetch_state(self, stack_name, resources):
         iam = aws_stack.connect_to_service("iam")
-        service_name = self.resolve_refs_recursively(
-            stack_name, self.props["AWSServiceName"], resources
-        )
+        service_name = self.props["AWSServiceName"]
         path = f"{SERVICE_LINKED_ROLE_PATH_PREFIX}/{service_name}"
         roles = iam.list_roles(PathPrefix=path)["Roles"]
         for role in roles:
@@ -453,7 +446,6 @@ class IAMPolicy(GenericBaseModel):
         def _create(resource_id, resources, resource_type, func, stack_name, *args, **kwargs):
             iam = aws_stack.connect_to_service("iam")
             props = resources[resource_id]["Properties"]
-            cls.resolve_refs_recursively(stack_name, props, resources)
             policy_doc = json.dumps(remove_none_values(props["PolicyDocument"]))
             policy_name = props["PolicyName"]
             for role in props.get("Roles", []):
@@ -496,7 +488,6 @@ class IAMPolicy(GenericBaseModel):
         if managed_policy:
             result["policy"] = iam.get_policy(PolicyArn=arns.policy_arn(policy_name))
         for role in roles:
-            role = obj.resolve_refs_recursively(stack_name, role, resources)
             policies = (
                 _filter(iam.list_attached_role_policies(RoleName=role))
                 if managed_policy
@@ -504,7 +495,6 @@ class IAMPolicy(GenericBaseModel):
             )
             result["role:%s" % role] = policies
         for user in users:
-            user = obj.resolve_refs_recursively(stack_name, user, resources)
             policies = (
                 _filter(iam.list_attached_user_policies(UserName=user))
                 if managed_policy
@@ -512,7 +502,6 @@ class IAMPolicy(GenericBaseModel):
             )
             result["user:%s" % user] = policies
         for group in groups:
-            group = obj.resolve_refs_recursively(stack_name, group, resources)
             policies = (
                 _filter(iam.list_attached_group_policies(GroupName=group))
                 if managed_policy
@@ -612,13 +601,8 @@ class IAMGroup(GenericBaseModel):
     def get_physical_resource_id(self, attribute=None, **kwargs):
         return self.props.get("GroupName")
 
-    def get_resource_name(self):
-        return self.props.get("GroupName")
-
     def fetch_state(self, stack_name, resources):
-        group_name = self.resolve_refs_recursively(
-            stack_name, self.props.get("GroupName"), resources
-        )
+        group_name = self.props.get("GroupName")
         return aws_stack.connect_to_service("iam").get_group(GroupName=group_name)["Group"]
 
     def update_resource(self, new_resource, stack_name, resources):
