@@ -4,15 +4,14 @@ import re
 from botocore.exceptions import ClientError
 
 from localstack.constants import S3_STATIC_WEBSITE_HOSTNAME, S3_VIRTUAL_HOSTNAME
+from localstack.services.cloudformation.cfn_utils import rename_params
 from localstack.services.cloudformation.deployment_utils import (
-    PLACEHOLDER_RESOURCE_NAME,
     dump_json_params,
     generate_default_name,
 )
 from localstack.services.cloudformation.service_models import GenericBaseModel
 from localstack.services.s3 import s3_listener, s3_utils
 from localstack.utils.aws import arns, aws_stack
-from localstack.utils.cloudformation.cfn_utils import rename_params
 from localstack.utils.common import canonical_json, md5
 from localstack.utils.testutil import delete_all_s3_objects
 
@@ -27,8 +26,7 @@ class S3BucketPolicy(GenericBaseModel):
         return policy and md5(canonical_json(json.loads(policy)))
 
     def fetch_state(self, stack_name, resources):
-        bucket_name = self.props.get("Bucket") or self.resource_id
-        bucket_name = self.resolve_refs_recursively(stack_name, bucket_name, resources)
+        bucket_name = self.props.get("Bucket") or self.logical_resource_id
         return aws_stack.connect_to_service("s3").get_bucket_policy(Bucket=bucket_name)
 
     @staticmethod
@@ -50,9 +48,6 @@ class S3Bucket(GenericBaseModel):
     def cloudformation_type():
         return "AWS::S3::Bucket"
 
-    def get_resource_name(self):
-        return self.normalize_bucket_name(self.props.get("BucketName"))
-
     @staticmethod
     def normalize_bucket_name(bucket_name):
         return s3_utils.normalize_bucket_name(bucket_name)
@@ -105,7 +100,7 @@ class S3Bucket(GenericBaseModel):
 
             # construct final result
             result = {
-                "Bucket": params.get("BucketName") or PLACEHOLDER_RESOURCE_NAME,
+                "Bucket": params.get("BucketName"),
                 "NotificationConfiguration": {
                     "LambdaFunctionConfigurations": lambda_configs,
                     "QueueConfigurations": queue_configs,
@@ -194,7 +189,6 @@ class S3Bucket(GenericBaseModel):
     def fetch_state(self, stack_name, resources):
         props = self.props
         bucket_name = self._get_bucket_name()
-        bucket_name = self.resolve_refs_recursively(stack_name, bucket_name, resources)
         bucket_name = self.normalize_bucket_name(bucket_name)
         s3_client = aws_stack.connect_to_service("s3")
         response = s3_client.get_bucket_location(Bucket=bucket_name)
@@ -229,4 +223,4 @@ class S3Bucket(GenericBaseModel):
         return bucket_name
 
     def _get_bucket_name(self):
-        return self.props.get("BucketName") or self.resource_id
+        return self.props.get("BucketName") or self.logical_resource_id
