@@ -29,8 +29,7 @@ class SecretsManagerSecret(GenericBaseModel):
         return super(SecretsManagerSecret, self).get_cfn_attribute(attribute_name)
 
     def fetch_state(self, stack_name, resources):
-        secret_name = self.props.get("Name") or self.resource_id
-        secret_name = self.resolve_refs_recursively(stack_name, secret_name, resources)
+        secret_name = self.props.get("Name") or self.logical_resource_id
         result = aws_stack.connect_to_service("secretsmanager").describe_secret(
             SecretId=secret_name
         )
@@ -159,7 +158,7 @@ class SecretsManagerResourcePolicy(GenericBaseModel):
         return arns.secretsmanager_secret_arn(self.props.get("SecretId"))
 
     def fetch_state(self, stack_name, resources):
-        secret_id = self.resolve_refs_recursively(stack_name, self.props.get("SecretId"), resources)
+        secret_id = self.props.get("SecretId")
         result = aws_stack.connect_to_service("secretsmanager").get_resource_policy(
             SecretId=secret_id
         )
