@@ -7,10 +7,16 @@ import subprocess
 import sys
 import threading
 from typing import Dict
+from urllib.parse import urlparse
 
 from requests.models import Response
 
 from localstack import config
+from localstack.aws.accounts import (
+    get_account_id_from_access_key_id,
+    set_aws_access_key_id,
+    set_aws_account_id,
+)
 from localstack.aws.protocol.service_router import determine_aws_service_name
 from localstack.constants import (
     HEADER_LOCALSTACK_ACCOUNT_ID,
@@ -20,6 +26,7 @@ from localstack.constants import (
     LOCALHOST_IP,
     LOCALSTACK_ROOT_FOLDER,
     LS_LOG_TRACE_INTERNAL,
+    TEST_AWS_ACCESS_KEY_ID,
 )
 from localstack.http import Router
 from localstack.http.adapters import create_request_from_parts
@@ -28,15 +35,19 @@ from localstack.runtime import events
 from localstack.services.generic_proxy import ProxyListener, modify_and_forward, start_proxy_server
 from localstack.services.infra import PROXY_LISTENERS
 from localstack.services.plugins import SERVICE_PLUGINS
-from localstack.utils import persistence
 from localstack.utils.aws import aws_stack
-from localstack.utils.aws.aws_stack import is_internal_call_context, set_default_region_in_headers
+from localstack.utils.aws.aws_stack import (
+    extract_access_key_id_from_auth_header,
+    is_internal_call_context,
+    set_default_region_in_headers,
+)
 from localstack.utils.functions import empty_context_manager
 from localstack.utils.http import parse_request_data
 from localstack.utils.http import safe_requests as requests
 from localstack.utils.net import is_port_open
 from localstack.utils.run import is_root, run
 from localstack.utils.server.http2_server import HTTPErrorResponse
+from localstack.utils.server.proxy_server import start_tcp_proxy
 from localstack.utils.strings import to_bytes, truncate
 from localstack.utils.sync import sleep_forever
 from localstack.utils.threads import TMP_THREADS, start_thread
@@ -92,6 +103,16 @@ class ProxyListenerEdge(ProxyListener):
             re.sub(r"^([^:]+://[^/]+).*", r"\1", orig_req_url) or "http://%s" % host
         )
 
+        # Obtain the access key ID and save it in the thread context
+        access_key_id = extract_access_key_id_from_auth_header(headers) or TEST_AWS_ACCESS_KEY_ID
+        set_aws_access_key_id(access_key_id)
+        # Obtain the account ID
+        account_id = get_account_id_from_access_key_id(access_key_id)
+        # Save the same account ID in the thread context
+        set_aws_account_id(account_id)
+        # Make Moto use the same Account ID as LocalStack
+        headers["x-moto-account-id"] = account_id
+
         # re-create an HTTP request from the given parts
         request = create_request_from_parts(method, path, data, headers)
 
@@ -162,7 +183,7 @@ class ProxyListenerEdge(ProxyListener):
         self._require_service(api)
 
         lock_ctx = BOOTSTRAP_LOCK
-        if is_internal_call or persistence.is_persistence_restored():
+        if is_internal_call or not config.is_persistence_enabled():
             lock_ctx = empty_context_manager()
 
         with lock_ctx:
@@ -336,7 +357,6 @@ def is_trace_logging_enabled(headers) -> bool:
 
 def do_start_edge(bind_address, port, use_ssl, asynchronous=False):
     start_dns_server(asynchronous=True)
-
     if config.LEGACY_EDGE_PROXY:
         serve = do_start_edge_proxy
     else:
@@ -388,11 +408,13 @@ def ensure_can_use_sudo():
         run("sudo -v", stdin=True)
 
 
-def start_component(component: str, port=None, use_ssl=True, asynchronous=False):
+def start_component(component: str, port=None):
     if component == "edge":
-        return start_edge(port=port, use_ssl=use_ssl, asynchronous=asynchronous)
+        return start_edge(port=port)
     if component == "dns":
-        return start_dns_server(asynchronous=asynchronous)
+        return start_dns_server()
+    if component == "proxy":
+        return start_proxy(port=port)
     raise Exception("Unexpected component name '%s' received during start up" % component)
 
 
@@ -427,6 +449,35 @@ def start_dns_server(asynchronous=False):
         pass
 
 
+def start_proxy(port, asynchronous=False):
+    """
+    Starts a TCP proxy to perform a low-level forwarding of incoming requests.
+    The proxy's source port (given as method argument) is bound to the EDGE_BIND_HOST.
+    The target IP is always 127.0.0.1.
+    The target port is parsed from the EDGE_FORWARD_URL (for compatibility with the legacy edge proxy forwarding).
+    All other parts of the EDGE_FORWARD_URL are _not_ used anymore.
+
+    :param port: source port
+    :param asynchronous: False if the function should join the proxy thread and block until it terminates.
+    :return: created thread executing the proxy
+    """
+    destination_port = urlparse(config.EDGE_FORWARD_URL).port
+    if not destination_port or destination_port < 1 or destination_port > 65535:
+        raise ValueError("EDGE_FORWARD_URL does not contain a valid port.")
+
+    src = f"{config.EDGE_BIND_HOST}:{port}"
+    dst = f"{config.LOCALHOST_IP}:{destination_port}"
+
+    LOG.debug("Starting Local TCP Proxy: %s -> %s", src, dst)
+    proxy = start_thread(
+        lambda *args, **kwargs: start_tcp_proxy(src=src, dst=dst, handler=None, **kwargs),
+        name="edge-tcp-proxy",
+    )
+    if not asynchronous:
+        proxy.join()
+    return proxy
+
+
 def start_edge(port=None, use_ssl=True, asynchronous=False):
     if not port:
         port = config.EDGE_PORT
@@ -454,7 +505,13 @@ def start_edge(port=None, use_ssl=True, asynchronous=False):
     # register a signal handler to terminate the sudo process later on
     TMP_THREADS.append(Terminator())
 
-    return run_process_as_sudo("edge", port, asynchronous=asynchronous)
+    # start the TCP proxy
+    env_vars = {
+        "DEBUG": os.environ.get("DEBUG", ""),
+        "EDGE_FORWARD_URL": config.get_edge_url(),
+        "EDGE_BIND_HOST": config.EDGE_BIND_HOST,
+    }
+    return run_process_as_sudo("proxy", port, env_vars=env_vars, asynchronous=asynchronous)
 
 
 def run_process_as_sudo(component, port, asynchronous=False, env_vars=None):
@@ -468,10 +525,6 @@ def run_process_as_sudo(component, port, asynchronous=False, env_vars=None):
     # prepare environment
     env_vars = env_vars or {}
     env_vars["PYTHONPATH"] = f".:{LOCALSTACK_ROOT_FOLDER}"
-    # FIXME the edge proxy forwarding is not yet supported for the new HTTP gateway
-    env_vars["LEGACY_EDGE_PROXY"] = 1
-    env_vars["EDGE_FORWARD_URL"] = config.get_edge_url()
-    env_vars["EDGE_BIND_HOST"] = config.EDGE_BIND_HOST
     env_vars_str = env_vars_to_string(env_vars)
 
     # start the process as sudo
