@@ -69,7 +69,6 @@ from localstack.aws.api.opensearch import (
     DomainStatus,
     VersionString,
 )
-from localstack.utils.analytics import event_publisher
 from localstack.utils.aws import aws_stack
 
 
@@ -142,11 +141,12 @@ def _clusterconfig_to_opensearch(
 ) -> Optional[ClusterConfig]:
     if elasticsearch_cluster_config is not None:
         result = cast(ClusterConfig, elasticsearch_cluster_config)
-        result["InstanceType"] = _instancetype_to_opensearch(result.get("InstanceType"))
-        result["DedicatedMasterType"] = _instancetype_to_opensearch(
-            result.get("DedicatedMasterType")
-        )
-        result["WarmType"] = _instancetype_to_opensearch(result.get("WarmType"))
+        if instance_type := result.get("InstanceType"):
+            result["InstanceType"] = _instancetype_to_opensearch(instance_type)
+        if dedicated_master_type := result.get("DedicatedMasterType"):
+            result["DedicatedMasterType"] = _instancetype_to_opensearch(dedicated_master_type)
+        if warm_type := result.get("WarmType"):
+            result["WarmType"] = _instancetype_to_opensearch(warm_type)
         return result
 
 
@@ -262,12 +262,6 @@ class EsProvider(EsApi):
         with exception_mapper():
             domain_status = opensearch_client.create_domain(**kwargs)["DomainStatus"]
 
-        # record event
-        event_publisher.fire_event(
-            event_publisher.EVENT_ES_CREATE_DOMAIN,
-            payload={"n": event_publisher.get_hash(domain_name)},
-        )
-
         status = _domainstatus_from_opensearch(domain_status)
         return CreateElasticsearchDomainResponse(DomainStatus=status)
 
@@ -281,12 +275,6 @@ class EsProvider(EsApi):
                 DomainName=domain_name,
             )["DomainStatus"]
 
-        # record event
-        event_publisher.fire_event(
-            event_publisher.EVENT_ES_DELETE_DOMAIN,
-            payload={"n": event_publisher.get_hash(domain_name)},
-        )
-
         status = _domainstatus_from_opensearch(domain_status)
         return DeleteElasticsearchDomainResponse(DomainStatus=status)
 
