@@ -1,5 +1,5 @@
 import logging
-import time
+import threading
 
 from crontab import CronTab
 
@@ -9,7 +9,7 @@ from localstack.utils.run import FuncThread
 LOG = logging.getLogger(__name__)
 
 
-class Job(object):
+class Job:
     def __init__(self, job_func, schedule, enabled):
         self.job_func = job_func
         self.schedule = schedule
@@ -21,7 +21,7 @@ class Job(object):
             if self.should_run_now() and self.is_enabled:
                 self.do_run()
         except Exception as e:
-            LOG.debug("Unable to run scheduled function %s: %s" % (self.job_func, e))
+            LOG.debug("Unable to run scheduled function %s: %s", self.job_func, e)
 
     def should_run_now(self):
         schedule = CronTab(self.schedule)
@@ -29,16 +29,18 @@ class Job(object):
         return delay_secs is not None and delay_secs < 60
 
     def do_run(self):
-        FuncThread(self.job_func).start()
+        FuncThread(self.job_func, name="events-job-run").start()
 
 
-class JobScheduler(object):
+class JobScheduler:
 
     _instance = None
 
     def __init__(self):
+        # TODO: introduce RLock for mutating jobs list
         self.jobs = []
         self.thread = None
+        self._stop_event = threading.Event()
 
     def add_job(self, job_func, schedule, enabled=True):
         job = Job(job_func, schedule, enabled=enabled)
@@ -60,7 +62,7 @@ class JobScheduler(object):
                 i += 1
 
     def loop(self, *args):
-        while True:
+        while not self._stop_event.is_set():
             try:
                 for job in list(self.jobs):
                     job.run()
@@ -68,10 +70,10 @@ class JobScheduler(object):
                 pass
             # This is a simple heuristic to cause the loop to run apprx every minute
             # TODO: we should keep track of jobs execution times, to avoid duplicate executions
-            time.sleep(59.9)
+            self._stop_event.wait(timeout=59.9)
 
     def start_loop(self):
-        self.thread = FuncThread(self.loop)
+        self.thread = FuncThread(self.loop, name="events-jobscheduler-loop")
         self.thread.start()
 
     @classmethod
@@ -86,3 +88,10 @@ class JobScheduler(object):
         if not instance.thread:
             instance.start_loop()
         return instance
+
+    @classmethod
+    def shutdown(cls):
+        instance = cls.instance()
+        if not instance.thread:
+            return
+        instance._stop_event.set()
