@@ -7,7 +7,6 @@ from localstack.services.stores import (
     CrossRegionAttribute,
     LocalAttribute,
 )
-from localstack.utils.kinesis.kinesis_connector import KinesisProcessorThread
 from localstack.utils.tagging import TaggingService
 
 
@@ -15,8 +14,6 @@ class FirehoseStore(BaseStore):
     # maps delivery stream names to DeliveryStreamDescription
     delivery_streams: Dict[str, DeliveryStreamDescription] = LocalAttribute(default=dict)
 
-    kinesis_listeners: Dict[str, KinesisProcessorThread] = LocalAttribute(default=dict)
-
     # static tagging service instance
     TAGS = CrossRegionAttribute(default=TaggingService)
 
