@@ -67,6 +67,7 @@ class KinesisMockServer(Server):
             # LocalStack uses only one - the insecure one. Block the secure port to avoid conflicts.
             "KINESIS_MOCK_TLS_PORT": get_free_tcp_port(),
             "SHARD_LIMIT": config.KINESIS_SHARD_LIMIT,
+            "ON_DEMAND_STREAM_COUNT_LIMIT": config.KINESIS_ON_DEMAND_STREAM_COUNT_LIMIT,
             "AWS_ACCOUNT_ID": self._account_id,
         }
 
@@ -80,6 +81,7 @@ class KinesisMockServer(Server):
             "MERGE_SHARDS_DURATION",
             "SPLIT_SHARD_DURATION",
             "UPDATE_SHARD_COUNT_DURATION",
+            "UPDATE_STREAM_MODE_DURATION",
         ]
         for param in latency_params:
             env_vars[param] = self._latency
