@@ -1,12 +1,11 @@
 import logging
-import threading
-from typing import Optional
 
 from moto.server import DomainDispatcherApplication, create_backend_app
 from werkzeug.serving import make_server
 
 from localstack import constants
 from localstack.utils.net import get_free_tcp_port
+from localstack.utils.objects import singleton_factory
 from localstack.utils.serving import Server
 
 LOG = logging.getLogger(__name__)
@@ -30,24 +29,15 @@ class MotoServer(Server):
         self.server.shutdown()
 
 
-_mutex = threading.RLock()
-_server: Optional[MotoServer] = None
-
-
-def get_moto_server(timeout=10) -> MotoServer:
+@singleton_factory
+def get_moto_server() -> MotoServer:
     """
     Returns the MotoServer singleton or creates it and waits for it to become ready.
     """
-    global _server, _mutex
+    server = MotoServer(port=get_free_tcp_port(), host=constants.BIND_HOST)
+    server.start()
 
-    with _mutex:
-        if _server:
-            return _server
+    if not server.wait_is_up(10):
+        raise TimeoutError("gave up waiting for moto server on %s" % server.url)
 
-        _server = MotoServer(port=get_free_tcp_port(), host=constants.BIND_HOST)
-        _server.start()
-
-        if not _server.wait_is_up(timeout):
-            raise TimeoutError("gave up waiting for moto server on %s" % _server.url)
-
-        return _server
+    return server
