@@ -1,6 +1,5 @@
 from localstack import config
 from localstack.aws.forwarder import HttpFallbackDispatcher
-from localstack.aws.proxy import AwsApiListener
 from localstack.services.moto import MotoFallbackDispatcher
 from localstack.services.plugins import Service, aws_provider
 
@@ -11,8 +10,7 @@ def acm():
     from localstack.services.moto import MotoFallbackDispatcher
 
     provider = AcmProvider()
-
-    return Service("acm", listener=AwsApiListener("acm", MotoFallbackDispatcher(provider)))
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider(api="apigateway")
@@ -20,9 +18,7 @@ def apigateway():
     from localstack.services.apigateway.provider import ApigatewayProvider
 
     provider = ApigatewayProvider()
-    listener = AwsApiListener("apigateway", MotoFallbackDispatcher(provider))
-
-    return Service("apigateway", listener=listener, lifecycle_hook=provider)
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
@@ -30,92 +26,68 @@ def cloudformation():
     from localstack.services.cloudformation.provider import CloudformationProvider
 
     provider = CloudformationProvider()
-
-    return Service("cloudformation", listener=AwsApiListener("cloudformation", provider))
+    return Service.for_provider(provider)
 
 
 @aws_provider(api="config")
 def awsconfig():
     from localstack.services.configservice.provider import ConfigProvider
-    from localstack.services.moto import MotoFallbackDispatcher
 
     provider = ConfigProvider()
-    return Service("config", listener=AwsApiListener("config", MotoFallbackDispatcher(provider)))
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
 def cloudwatch():
     from localstack.services.cloudwatch.provider import CloudwatchProvider
-    from localstack.services.moto import MotoFallbackDispatcher
 
     provider = CloudwatchProvider()
-    listener = AwsApiListener("cloudwatch", MotoFallbackDispatcher(provider))
-
-    return Service(
-        "cloudwatch",
-        listener=listener,
-        lifecycle_hook=provider,
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
 def dynamodb():
-    from localstack.aws.forwarder import HttpFallbackDispatcher
     from localstack.services.dynamodb.provider import DynamoDBProvider
 
     provider = DynamoDBProvider()
-    listener = AwsApiListener(
-        "dynamodb", HttpFallbackDispatcher(provider, provider.get_forward_url)
-    )
-
-    return Service(
-        "dynamodb",
-        listener=listener,
-        lifecycle_hook=provider,
+    return Service.for_provider(
+        provider,
+        dispatch_table_factory=lambda _provider: HttpFallbackDispatcher(
+            _provider, _provider.get_forward_url
+        ),
     )
 
 
 @aws_provider()
 def dynamodbstreams():
-    from localstack.aws.proxy import AwsApiListener
     from localstack.services.dynamodbstreams.provider import DynamoDBStreamsProvider
 
     provider = DynamoDBStreamsProvider()
-    return Service(
-        "dynamodbstreams",
-        listener=AwsApiListener("dynamodbstreams", provider),
-        lifecycle_hook=provider,
-    )
+    return Service.for_provider(provider)
 
 
 @aws_provider()
 def ec2():
     from localstack.services.ec2.provider import Ec2Provider
-    from localstack.services.moto import MotoFallbackDispatcher
 
     provider = Ec2Provider()
-    return Service(
-        "ec2",
-        listener=AwsApiListener("ec2", MotoFallbackDispatcher(provider)),
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
 def es():
-    from localstack.aws.proxy import AwsApiListener
     from localstack.services.es.provider import EsProvider
 
     provider = EsProvider()
-    return Service("es", listener=AwsApiListener("es", provider))
+    return Service.for_provider(provider)
 
 
 @aws_provider()
 def firehose():
-    from localstack.aws.proxy import AwsApiListener
     from localstack.services.firehose.provider import FirehoseProvider
 
     provider = FirehoseProvider()
-    return Service("firehose", listener=AwsApiListener("firehose", provider))
+    return Service.for_provider(provider)
 
 
 @aws_provider()
@@ -124,10 +96,7 @@ def iam():
     from localstack.services.moto import MotoFallbackDispatcher
 
     provider = IamProvider()
-    return Service(
-        "iam",
-        listener=AwsApiListener("iam", MotoFallbackDispatcher(provider)),
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
@@ -135,7 +104,7 @@ def sts():
     from localstack.services.sts.provider import StsProvider
 
     provider = StsProvider()
-    return Service("sts", listener=AwsApiListener("sts", MotoFallbackDispatcher(provider)))
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
@@ -143,26 +112,31 @@ def kinesis():
     from localstack.services.kinesis.provider import KinesisProvider
 
     provider = KinesisProvider()
-    listener = AwsApiListener("kinesis", HttpFallbackDispatcher(provider, provider.get_forward_url))
-    return Service(
-        "kinesis",
-        listener=listener,
-        lifecycle_hook=provider,
+    return Service.for_provider(
+        provider,
+        dispatch_table_factory=lambda _provider: HttpFallbackDispatcher(
+            _provider, _provider.get_forward_url
+        ),
     )
 
 
 @aws_provider()
 def kms():
     if config.KMS_PROVIDER == "local-kms":
-        from localstack.services.kms import kms_starter
+        from localstack.services.kms.local_kms_provider import LocalKmsProvider
 
-        return Service("kms", start=kms_starter.start_kms_local)
+        provider = LocalKmsProvider()
+        return Service.for_provider(
+            provider,
+            dispatch_table_factory=lambda _provider: HttpFallbackDispatcher(
+                _provider, _provider.start_and_get_backend
+            ),
+        )
 
-    # fall back to default provider
     from localstack.services.kms.provider import KmsProvider
 
     provider = KmsProvider()
-    return Service("kms", listener=AwsApiListener("kms", provider))
+    return Service.for_provider(provider)
 
 
 @aws_provider(api="lambda")
@@ -179,12 +153,18 @@ def awslambda():
 
 @aws_provider(api="lambda", name="asf")
 def awslambda_asf():
-    from localstack.aws.proxy import AwsApiListener
     from localstack.services.awslambda.provider import LambdaProvider
 
     provider = LambdaProvider()
+    return Service.for_provider(provider)
 
-    return Service("lambda", listener=AwsApiListener("lambda", provider), lifecycle_hook=provider)
+
+@aws_provider(api="lambda", name="v2")
+def awslambda_v2():
+    from localstack.services.awslambda.provider import LambdaProvider
+
+    provider = LambdaProvider()
+    return Service.for_provider(provider)
 
 
 @aws_provider()
@@ -192,17 +172,15 @@ def logs():
     from localstack.services.logs.provider import LogsProvider
 
     provider = LogsProvider()
-    listener = AwsApiListener("logs", MotoFallbackDispatcher(provider))
-    return Service("logs", listener=listener)
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
 def opensearch():
-    from localstack.aws.proxy import AwsApiListener
     from localstack.services.opensearch.provider import OpensearchProvider
 
     provider = OpensearchProvider()
-    return Service("opensearch", listener=AwsApiListener("opensearch", provider))
+    return Service.for_provider(provider)
 
 
 @aws_provider()
@@ -210,9 +188,7 @@ def redshift():
     from localstack.services.redshift.provider import RedshiftProvider
 
     provider = RedshiftProvider()
-    listener = AwsApiListener("redshift", MotoFallbackDispatcher(provider))
-
-    return Service("redshift", listener=listener)
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
@@ -220,8 +196,7 @@ def route53():
     from localstack.services.route53.provider import Route53Provider
 
     provider = Route53Provider()
-
-    return Service("route53", listener=AwsApiListener("route53", MotoFallbackDispatcher(provider)))
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
@@ -229,11 +204,7 @@ def route53resolver():
     from localstack.services.route53resolver.provider import Route53ResolverProvider
 
     provider = Route53ResolverProvider()
-
-    return Service(
-        "route53resolver",
-        listener=AwsApiListener("route53resolver", MotoFallbackDispatcher(provider)),
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider(api="s3", name="default")
@@ -250,63 +221,51 @@ def s3_asf():
     from localstack.services.s3.provider import S3Provider
 
     provider = S3Provider()
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
-    return Service(
-        "s3",
-        listener=AwsApiListener("s3", MotoFallbackDispatcher(provider)),
-        lifecycle_hook=provider,
-    )
+
+@aws_provider(api="s3", name="v2")
+def s3_v2():
+    from localstack.services.s3.provider import S3Provider
+
+    provider = S3Provider()
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
 def s3control():
-    from localstack.services.moto import MotoFallbackDispatcher
     from localstack.services.s3control.provider import S3ControlProvider
 
     provider = S3ControlProvider()
-    return Service(
-        "s3control", listener=AwsApiListener("s3control", MotoFallbackDispatcher(provider))
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
 def secretsmanager():
-    from localstack.services.moto import MotoFallbackDispatcher
     from localstack.services.secretsmanager.provider import SecretsmanagerProvider
 
     provider = SecretsmanagerProvider()
-    return Service(
-        "secretsmanager",
-        listener=AwsApiListener("secretsmanager", MotoFallbackDispatcher(provider)),
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
 def ses():
-    from localstack.services.moto import MotoFallbackDispatcher
     from localstack.services.ses.provider import SesProvider
 
     provider = SesProvider()
-    return Service(
-        "ses",
-        listener=AwsApiListener("ses", MotoFallbackDispatcher(provider)),
-        lifecycle_hook=provider,
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
 def sns():
-    from localstack.aws.proxy import AwsApiListener
     from localstack.services.sns.provider import SnsProvider
 
     provider = SnsProvider()
-
-    return Service("sns", listener=AwsApiListener("sns", provider), lifecycle_hook=provider)
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
 def sqs():
-    from localstack.aws.proxy import AwsApiListener
     from localstack.services import edge
     from localstack.services.sqs import query_api
     from localstack.services.sqs.provider import SqsProvider
@@ -314,8 +273,7 @@ def sqs():
     query_api.register(edge.ROUTER)
 
     provider = SqsProvider()
-
-    return Service("sqs", listener=AwsApiListener("sqs", provider), lifecycle_hook=provider)
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
@@ -324,10 +282,7 @@ def ssm():
     from localstack.services.ssm.provider import SsmProvider
 
     provider = SsmProvider()
-    return Service(
-        "ssm",
-        listener=AwsApiListener("ssm", MotoFallbackDispatcher(provider)),
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
@@ -336,11 +291,7 @@ def events():
     from localstack.services.moto import MotoFallbackDispatcher
 
     provider = EventsProvider()
-    return Service(
-        "events",
-        listener=AwsApiListener("events", MotoFallbackDispatcher(provider)),
-        lifecycle_hook=provider,
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
@@ -348,13 +299,11 @@ def stepfunctions():
     from localstack.services.stepfunctions.provider import StepFunctionsProvider
 
     provider = StepFunctionsProvider()
-    listener = AwsApiListener(
-        "stepfunctions", HttpFallbackDispatcher(provider, provider.get_forward_url)
-    )
-    return Service(
-        "stepfunctions",
-        listener=listener,
-        lifecycle_hook=provider,
+    return Service.for_provider(
+        provider,
+        dispatch_table_factory=lambda _provider: HttpFallbackDispatcher(
+            _provider, _provider.get_forward_url
+        ),
     )
 
 
@@ -364,58 +313,38 @@ def swf():
     from localstack.services.swf.provider import SWFProvider
 
     provider = SWFProvider()
-    return Service(
-        "swf",
-        listener=AwsApiListener("swf", MotoFallbackDispatcher(provider)),
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
 def resourcegroupstaggingapi():
-    from localstack.services.moto import MotoFallbackDispatcher
     from localstack.services.resourcegroupstaggingapi.provider import (
         ResourcegroupstaggingapiProvider,
     )
 
     provider = ResourcegroupstaggingapiProvider()
-    return Service(
-        "resourcegroupstaggingapi",
-        listener=AwsApiListener("resourcegroupstaggingapi", MotoFallbackDispatcher(provider)),
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider(api="resource-groups")
 def resource_groups():
-    from localstack.services.moto import MotoFallbackDispatcher
     from localstack.services.resourcegroups.provider import ResourceGroupsProvider
 
     provider = ResourceGroupsProvider()
-    return Service(
-        "resource-groups",
-        listener=AwsApiListener("resource-groups", MotoFallbackDispatcher(provider)),
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
 def support():
-    from localstack.services.moto import MotoFallbackDispatcher
     from localstack.services.support.provider import SupportProvider
 
     provider = SupportProvider()
-    return Service(
-        "support",
-        listener=AwsApiListener("support", MotoFallbackDispatcher(provider)),
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
 
 
 @aws_provider()
 def transcribe():
-    from localstack.services.moto import MotoFallbackDispatcher
     from localstack.services.transcribe.provider import TranscribeProvider
 
     provider = TranscribeProvider()
-    return Service(
-        "transcribe",
-        listener=AwsApiListener("transcribe", MotoFallbackDispatcher(provider)),
-        lifecycle_hook=provider,
-    )
+    return Service.for_provider(provider, dispatch_table_factory=MotoFallbackDispatcher)
