@@ -28,6 +28,7 @@ from localstack.aws.api.s3 import (
     TopicArn,
     TopicConfiguration,
 )
+from localstack.aws.protocol.serializer import gen_amzn_requestid_long
 from localstack.config import DEFAULT_REGION
 from localstack.services.s3.models import get_moto_s3_backend
 from localstack.services.s3.utils import (
@@ -51,6 +52,7 @@ EVENT_OPERATION_MAP = {
     "DeleteObjectTagging": Event.s3_ObjectTagging_Delete,
     "DeleteObject": Event.s3_ObjectRemoved_Delete,
     "DeleteObjects": Event.s3_ObjectRemoved_Delete,
+    "PutObjectAcl": Event.s3_ObjectAcl_Put,
 }
 
 HEADER_AMZN_XRAY = "X-Amzn-Trace-Id"
@@ -286,10 +288,11 @@ class BaseNotifier:
         if "created" in ctx.event_type.lower():
             record["s3"]["object"]["size"] = ctx.key_size
             record["s3"]["object"]["eTag"] = ctx.key_etag
-        if "ObjectTagging" in ctx.event_type:
+        if "ObjectTagging" in ctx.event_type or "ObjectAcl" in ctx.event_type:
             record["eventVersion"] = "2.3"
             record["s3"]["object"]["eTag"] = ctx.key_etag
             record["s3"]["object"].pop("sequencer")
+
         return {"Records": [record]}
 
 
@@ -454,7 +457,7 @@ class EventBridgeNotifier(BaseNotifier):
                 "etag": ctx.key_etag,
                 "sequencer": "0062E99A88DC407460",
             },
-            "request-id": "RKREYG1RN2X92YX6",
+            "request-id": gen_amzn_requestid_long(),
             "requester": "074255357339",
             "source-ip-address": "127.0.0.1",
             # TODO previously headers.get("X-Forwarded-For", "127.0.0.1").split(",")[0]
@@ -483,6 +486,11 @@ class EventBridgeNotifier(BaseNotifier):
                 "Object Tags Added" if "Put" in ctx.event_type else "Object Tags Deleted"
             )
 
+        elif "ObjectAcl" in ctx.event_type:
+            entry["DetailType"] = "Object ACL Updated"
+            event_details["object"].pop("size")
+            event_details["object"].pop("sequencer")
+
         entry["Detail"] = json.dumps(event_details)
         return entry
 
