@@ -31,7 +31,7 @@ from localstack.services.s3.utils import (
     S3_VIRTUAL_HOST_FORWARDED_HEADER,
     _create_invalid_argument_exc,
     capitalize_header_name_from_snake_case,
-    uses_host_addressing,
+    forwarded_from_virtual_host_addressed_request,
 )
 from localstack.utils.strings import to_bytes
 
@@ -498,10 +498,10 @@ def _find_valid_signature_through_ports(context: RequestContext) -> FindSigV4Res
             # the request has already been tested before the loop, skip
             if request_port == port:
                 continue
-            sigv4_context.update_host_port(port, request_port)
+            sigv4_context.update_host_port(new_host_port=port, original_host_port=request_port)
 
         else:
-            sigv4_context.update_host_port(port)
+            sigv4_context.update_host_port(new_host_port=port)
 
         # we ignore the additional data because we want the exception raised to match the original request
         signature, _, _ = sigv4_context.get_signature_data()
@@ -534,10 +534,11 @@ class S3SigV4SignatureContext:
         self.signed_headers = sig_headers
         self.request_query_string = qs
 
-        if uses_host_addressing(self._headers):
+        if forwarded_from_virtual_host_addressed_request(self._headers):
             netloc = self._headers.get(S3_VIRTUAL_HOST_FORWARDED_HEADER)
             self.host = netloc
             self._original_host = netloc
+            self.signed_headers["host"] = netloc
             # the request comes from the Virtual Host router, we need to remove the bucket from the path
             splitted_path = self.request.path.split("/", maxsplit=2)
             self.path = f"/{splitted_path[-1]}"
@@ -557,7 +558,7 @@ class S3SigV4SignatureContext:
         :param original_host_port:
         :return:
         """
-        if new_host_port:
+        if original_host_port:
             updated_netloc = self._original_host.replace(original_host_port, new_host_port)
         else:
             updated_netloc = f"{self._original_host}{new_host_port}"
@@ -589,6 +590,30 @@ class S3SigV4SignatureContext:
         headers.pop("Authorization", None)
         signed_headers = self._query_parameters.get("X-Amz-SignedHeaders")
 
+        new_query_args = {}
+        for qs_parameter, qs_value in self._query_parameters.items():
+            # skip the signature
+            if qs_parameter == "X-Amz-Signature":
+                continue
+
+            qs_param_low = qs_parameter.lower()
+            if (
+                qs_parameter not in SIGNATURE_V4_PARAMS
+                and qs_param_low.startswith("x-amz-")
+                and qs_param_low not in headers
+                and qs_param_low in signed_headers
+            ):
+                # AWS JS SDK does not behave like boto, and will add some parameters as query string when signing when
+                # boto would not. this difference in behaviour would lead to pre-signed URLs generated by the JS SDK
+                # to be invalid for the boto signer.
+                # This fixes the behaviour by manually adding the parameter to the headers like boto would, if the SDK
+                # put them in the SignedHeaders
+                # this is especially valid for headers starting with x-amz-server-side-encryption, treated specially in
+                # the old JS SDK
+                headers.add(qs_param_low, qs_value)
+
+            new_query_args[qs_parameter] = qs_value
+
         signature_headers = {}
         not_signed_headers = []
         for header, value in headers.items():
@@ -607,9 +632,6 @@ class S3SigV4SignatureContext:
             )
             raise ex
 
-        new_query_args = {
-            arg: value for arg, value in self._query_parameters.items() if arg != "X-Amz-Signature"
-        }
         new_query_string = percent_encode_sequence(new_query_args)
         return signature_headers, new_query_string
 
