@@ -21,6 +21,7 @@ from requests.models import Request, Response
 
 from localstack import config, constants
 from localstack.aws.api import CommonServiceException
+from localstack.aws.protocol.serializer import gen_amzn_requestid_long
 from localstack.config import get_protocol as get_service_protocol
 from localstack.services.generic_proxy import ProxyListener
 from localstack.services.generic_proxy import append_cors_headers as _append_default_cors_headers
@@ -251,7 +252,7 @@ def get_event_message(
                 "userIdentity": {"principalId": "AIDAJDPLRKLG7UEXAMPLE"},
                 "requestParameters": {"sourceIPAddress": source_ip},
                 "responseElements": {
-                    "x-amz-request-id": short_uid(),
+                    "x-amz-request-id": gen_amzn_requestid_long(),
                     "x-amz-id-2": "eftixk72aD6Ap51TnqcoF8eFidJG9Z/2",  # Amazon S3 host that processed the request
                 },
                 "s3": {
@@ -419,7 +420,7 @@ def send_notification_for_subscriber(
                     "etag": object_data.get("ETag", ""),
                     "sequencer": "0062E99A88DC407460",
                 },
-                "request-id": "RKREYG1RN2X92YX6",
+                "request-id": gen_amzn_requestid_long(),
                 "requester": "074255357339",
                 "source-ip-address": source_ip,
             },
@@ -1611,12 +1612,11 @@ class ProxyListenerS3(ProxyListener):
 
         is_object_request = all(
             [
-                "/" in path[1:] or bucket_name_in_host or key,
                 # check if this is an actual put object request, because it could also be
                 # a put bucket request with a path like this: /bucket_name/
                 bucket_name_in_host
                 or key
-                or (len(path[1:].split("/")) > 1 and len(path[1:].split("/")[1]) > 0),
+                or (len(parsed.path[1:].split("/")) > 1 and len(parsed.path[1:].split("/")[1]) > 0),
             ]
         )
 
