@@ -2,8 +2,9 @@ import dataclasses
 import json
 import logging
 import os
+from collections import defaultdict
 from datetime import date, datetime, time, timezone
-from typing import TYPE_CHECKING, Any, Dict, Optional
+from typing import TYPE_CHECKING, Any, Dict, List, Optional
 
 from botocore.exceptions import ClientError
 from moto.ses import ses_backends
@@ -50,9 +51,11 @@ from localstack.aws.api.ses import (
     VerificationStatus,
 )
 from localstack.constants import TEST_AWS_SECRET_ACCESS_KEY
-from localstack.services.internal import get_internal_apis
+from localstack.http import Resource
+from localstack.services.internal import DeprecatedResource, get_internal_apis
 from localstack.services.moto import call_moto
 from localstack.services.plugins import ServiceLifecycleHook
+from localstack.services.ses.models import SentEmail, SentEmailBody
 from localstack.utils.aws import arns, aws_stack
 from localstack.utils.files import mkdir
 from localstack.utils.strings import long_uid, to_str
@@ -69,33 +72,27 @@ EMAILS: Dict[MessageId, Dict[str, Any]] = {}
 
 # Endpoint to access all the sent emails
 # (relative to LocalStack internal HTTP resources base endpoint)
-EMAILS_ENDPOINT = "/ses"
+EMAILS_ENDPOINT = "/_aws/ses"
 
 _EMAILS_ENDPOINT_REGISTERED = False
 
 
-def save_for_retrospection(id: str, region: str, **kwargs: Dict[str, Any]):
-    """Save a message for retrospection.
-
-    The email is saved to filesystem and is also made accessible via a service endpoint.
-
-    kwargs should consist of following keys related to the email:
-    - Body
-    - Destinations
-    - RawData
-    - Source
-    - Subject
-    - Template
-    - TemplateData
+def save_for_retrospection(sent_email: SentEmail):
     """
+    Save a message for retrospection.
+
+    The contents of the email is saved to filesystem. It can also be accessed via a service endpoint.
+    """
+    message_id = sent_email["Id"]
     ses_dir = os.path.join(config.dirs.data or config.dirs.tmp, "ses")
-
     mkdir(ses_dir)
-    path = os.path.join(ses_dir, id + ".json")
 
-    email = {"Id": id, "Timestamp": timestamp(), "Region": region, **kwargs}
+    path = os.path.join(ses_dir, message_id + ".json")
 
-    EMAILS[id] = email
+    if not sent_email.get("Timestamp"):
+        sent_email["Timestamp"] = timestamp()
+
+    EMAILS[message_id] = sent_email
 
     def _serialize(obj):
         """JSON serializer for timestamps."""
@@ -104,13 +101,22 @@ def save_for_retrospection(id: str, region: str, **kwargs: Dict[str, Any]):
         return obj.__dict__
 
     with open(path, "w") as f:
-        f.write(json.dumps(email, default=_serialize))
+        f.write(json.dumps(sent_email, default=_serialize))
 
     LOGGER.debug("Email saved at: %s", path)
 
 
+def recipients_from_destination(destination: Destination) -> List[str]:
+    """Get list of recipient email addresses from a Destination object."""
+    return (
+        destination.get("ToAddresses", [])
+        + destination.get("CcAddresses", [])
+        + destination.get("BccAddresses", [])
+    )
+
+
 def get_ses_backend(context: RequestContext) -> SESBackend:
-    return ses_backends[context.account_id]["global"]
+    return ses_backends[context.account_id][context.region]
 
 
 class SesServiceApiResource:
@@ -142,7 +148,23 @@ def register_ses_api_resource():
     global _EMAILS_ENDPOINT_REGISTERED
 
     if not _EMAILS_ENDPOINT_REGISTERED:
-        get_internal_apis().add(EMAILS_ENDPOINT, SesServiceApiResource())
+        ses_service_api_resource = SesServiceApiResource()
+        get_internal_apis().add(
+            Resource(
+                "/_localstack/ses",
+                DeprecatedResource(
+                    ses_service_api_resource,
+                    previous_path="/_localstack/ses",
+                    deprecation_version="1.4.0",
+                    new_path="/_aws/ses/",
+                ),
+            )
+        )
+
+        from localstack.services.edge import ROUTER
+
+        ROUTER.add(Resource(EMAILS_ENDPOINT, ses_service_api_resource))
+
         _EMAILS_ENDPOINT_REGISTERED = True
 
 
@@ -305,6 +327,8 @@ class SesProvider(SesApi, ServiceLifecycleHook):
 
         backend = get_ses_backend(context)
         emitter = SNSEmitter(context)
+        recipients = recipients_from_destination(destination)
+
         for event_destination in backend.config_set_event_destination.values():
             if not event_destination["Enabled"]:
                 continue
@@ -316,7 +340,8 @@ class SesProvider(SesApi, ServiceLifecycleHook):
             payload = SNSPayload(
                 message_id=response["MessageId"],
                 sender_email=source,
-                destination_addresses=destination["ToAddresses"],
+                destination_addresses=recipients,
+                tags=tags,
             )
             emitter.emit_send_event(payload, sns_destination_arn)
             emitter.emit_delivery_event(payload, sns_destination_arn)
@@ -325,12 +350,14 @@ class SesProvider(SesApi, ServiceLifecycleHook):
         html_part = message["Body"].get("Html", {}).get("Data")
 
         save_for_retrospection(
-            response["MessageId"],
-            context.region,
-            Source=source,
-            Destination=destination,
-            Subject=message["Subject"].get("Data"),
-            Body=dict(text_part=text_part, html_part=html_part),
+            SentEmail(
+                Id=response["MessageId"],
+                Region=context.region,
+                Destination=destination,
+                Source=source,
+                Subject=message["Subject"].get("Data"),
+                Body=SentEmailBody(text_part=text_part, html_part=html_part),
+            )
         )
 
         return response
@@ -355,6 +382,8 @@ class SesProvider(SesApi, ServiceLifecycleHook):
 
         backend = get_ses_backend(context)
         emitter = SNSEmitter(context)
+        recipients = recipients_from_destination(destination)
+
         for event_destination in backend.config_set_event_destination.values():
             if not event_destination["Enabled"]:
                 continue
@@ -366,18 +395,21 @@ class SesProvider(SesApi, ServiceLifecycleHook):
             payload = SNSPayload(
                 message_id=response["MessageId"],
                 sender_email=source,
-                destination_addresses=destination["ToAddresses"],
+                destination_addresses=recipients,
+                tags=tags,
             )
             emitter.emit_send_event(payload, sns_destination_arn, emit_source_arn=False)
             emitter.emit_delivery_event(payload, sns_destination_arn)
 
         save_for_retrospection(
-            response["MessageId"],
-            context.region,
-            Source=source,
-            Template=template,
-            TemplateData=template_data,
-            Destination=destination,
+            SentEmail(
+                Id=response["MessageId"],
+                Region=context.region,
+                Source=source,
+                Template=template,
+                TemplateData=template_data,
+                Destination=destination,
+            )
         )
 
         return response
@@ -406,8 +438,7 @@ class SesProvider(SesApi, ServiceLifecycleHook):
                 LOGGER.warning("Source not specified. Rejecting message.")
                 raise MessageRejected()
 
-        if destinations is None:
-            destinations = []
+        destinations = destinations or []
 
         backend = get_ses_backend(context)
         message = backend.send_raw_email(source, destinations, raw_data, context.region)
@@ -425,16 +456,18 @@ class SesProvider(SesApi, ServiceLifecycleHook):
                 message_id=response["MessageId"],
                 sender_email=source,
                 destination_addresses=destinations,
+                tags=tags,
             )
             emitter.emit_send_event(payload, sns_destination_arn)
             emitter.emit_delivery_event(payload, sns_destination_arn)
 
         save_for_retrospection(
-            message.id,
-            context.region,
-            Source=source or message.source,
-            Destination=destinations,
-            RawData=raw_data,
+            SentEmail(
+                Id=message.id,
+                Region=context.region,
+                Source=source or message.source,
+                RawData=raw_data,
+            )
         )
 
         return SendRawEmailResponse(MessageId=message.id)
@@ -462,6 +495,7 @@ class SNSPayload:
     message_id: str
     sender_email: Address
     destination_addresses: AddressList
+    tags: Optional[MessageTagList]
 
 
 class SNSEmitter:
@@ -493,6 +527,10 @@ class SNSEmitter:
     ):
         now = datetime.now(tz=timezone.utc)
 
+        tags = defaultdict(list)
+        for every in payload.tags or []:
+            tags[every["Name"]].append(every["Value"])
+
         event_payload = {
             "eventType": "Send",
             "mail": {
@@ -501,6 +539,7 @@ class SNSEmitter:
                 "sendingAccountId": self.context.account_id,
                 "destination": payload.destination_addresses,
                 "messageId": payload.message_id,
+                "tags": tags,
             },
             "send": {},
         }
@@ -523,6 +562,10 @@ class SNSEmitter:
     def emit_delivery_event(self, payload: SNSPayload, sns_topic_arn: str):
         now = datetime.now(tz=timezone.utc)
 
+        tags = defaultdict(list)
+        for every in payload.tags or []:
+            tags[every["Name"]].append(every["Value"])
+
         event_payload = {
             "eventType": "Delivery",
             "mail": {
@@ -532,6 +575,7 @@ class SNSEmitter:
                 "sendingAccountId": self.context.account_id,
                 "destination": payload.destination_addresses,
                 "messageId": payload.message_id,
+                "tags": tags,
             },
             "delivery": {
                 "recipients": payload.destination_addresses,
