@@ -1,4 +1,3 @@
-import base64
 import copy
 import hashlib
 import json
@@ -15,7 +14,7 @@ from moto.sqs.models import Message as MotoMessage
 
 from localstack import config
 from localstack.aws.accounts import get_aws_account_id
-from localstack.aws.api import RequestContext
+from localstack.aws.api import CommonServiceException, RequestContext, ServiceException
 from localstack.aws.api.sqs import (
     ActionNameList,
     AttributeNameList,
@@ -63,7 +62,11 @@ from localstack.aws.api.sqs import (
     Token,
     TooManyEntriesInBatchRequest,
 )
+from localstack.aws.protocol.serializer import aws_response_serializer, create_serializer
 from localstack.aws.spec import load_service
+from localstack.config import SQS_DISABLE_MAX_NUMBER_OF_MESSAGE_LIMIT
+from localstack.http import Request, route
+from localstack.services.edge import ROUTER
 from localstack.services.plugins import ServiceLifecycleHook
 from localstack.services.sqs import constants as sqs_constants
 from localstack.services.sqs.exceptions import InvalidParameterValue
@@ -76,9 +79,10 @@ from localstack.services.sqs.models import (
     StandardQueue,
     sqs_stores,
 )
-from localstack.services.sqs.utils import generate_message_id
+from localstack.services.sqs.utils import generate_message_id, parse_queue_url
 from localstack.utils.aws import aws_stack
 from localstack.utils.aws.arns import parse_arn
+from localstack.utils.aws.request_context import extract_region_from_headers
 from localstack.utils.cloudwatch.cloudwatch_util import publish_sqs_metric
 from localstack.utils.run import FuncThread
 from localstack.utils.scheduler import Scheduler
@@ -88,6 +92,15 @@ from localstack.utils.time import now
 
 LOG = logging.getLogger(__name__)
 
+MAX_NUMBER_OF_MESSAGES = 10
+
+
+class InvalidAddress(ServiceException):
+    code = "InvalidAddress"
+    message = "The address https://queue.amazonaws.com/ is not valid for this endpoint."
+    sender_fault = True
+    status_code = 404
+
 
 def assert_queue_name(queue_name: str, fifo: bool = False):
     if queue_name.endswith(".fifo"):
@@ -406,6 +419,118 @@ def check_fifo_id(fifo_id):
         )
 
 
+class SqsDeveloperEndpoints:
+    """
+    A set of SQS developer tool endpoints:
+
+    - ``/_aws/sqs/messages``: list SQS messages without side effects, compatible with ``ReceiveMessage``.
+    """
+
+    def __init__(self, stores=None):
+        self.stores = stores or sqs_stores
+        self.service = load_service("sqs")
+        self.serializer = create_serializer(self.service)
+
+    @route("/_aws/sqs/messages")
+    @aws_response_serializer("sqs", "ReceiveMessage")
+    def list_messages(self, request: Request) -> ReceiveMessageResult:
+        """
+        This endpoint expects a ``QueueUrl`` request parameter (either as query arg or form parameter), similar to
+        the ``ReceiveMessage`` operation. It will parse the Queue URL generated by one of the SQS endpoint strategies.
+        """
+        if "Action" in request.values and request.values["Action"] != "ReceiveMessage":
+            raise CommonServiceException(
+                "InvalidRequest", "This endpoint only accepts ReceiveMessage calls"
+            )
+
+        if not request.values.get("QueueUrl"):
+            raise QueueDoesNotExist()
+
+        try:
+            region, account_id, queue_name = parse_queue_url(request.values["QueueUrl"])
+        except ValueError:
+            LOG.exception("Error while parsing Queue URL from request values: %s", request.values)
+            raise InvalidAddress()
+
+        if not region:
+            region = extract_region_from_headers(request.headers)
+
+        return self._get_and_serialize_messages(request, region, account_id, queue_name)
+
+    @route("/_aws/sqs/messages/<region>/<account_id>/<queue_name>")
+    @aws_response_serializer("sqs", "ReceiveMessage")
+    def list_messages_for_queue_url(
+        self, request: Request, region: str, account_id: str, queue_name: str
+    ) -> ReceiveMessageResult:
+        """
+        This endpoint extracts the region, account_id, and queue_name directly from the URL rather than requiring the
+        QueueUrl as parameter.
+        """
+        if "Action" in request.values and request.values["Action"] != "ReceiveMessage":
+            raise CommonServiceException(
+                "InvalidRequest", "This endpoint only accepts ReceiveMessage calls"
+            )
+
+        return self._get_and_serialize_messages(request, region, account_id, queue_name)
+
+    def _get_and_serialize_messages(
+        self, request: Request, region: str, account_id: str, queue_name: str
+    ) -> ReceiveMessageResult:
+        try:
+            store = self.stores[account_id or get_aws_account_id()][
+                region or aws_stack.get_region()
+            ]
+            queue = store.queues[queue_name]
+        except KeyError:
+            LOG.info(
+                "no queue named %s in region %s and account %s", queue_name, region, account_id
+            )
+            raise QueueDoesNotExist()
+
+        messages = self._collect_visible_messages(queue)
+        return ReceiveMessageResult(Messages=messages)
+
+    def _collect_visible_messages(self, queue: SqsQueue) -> List[Message]:
+        """
+        Retrieves from a given SqsQueue all visible messages without causing any side-effects (not setting any
+        receive timestamps, receive counts, or visibility state).
+
+        FIXME: There's a bit of code-duplication here with the two layers of receive_message calls, which we
+         should consolidate at some point.
+
+        :param queue: the queue
+        :return: a list of messages
+        """
+        receipt_handle = "SQS/BACKDOOR/ACCESS"  # dummy receipt handle
+
+        messages = []
+
+        for sqs_message in queue.visible.queue:
+            message: Message = copy.deepcopy(sqs_message.message)
+            messages.append(message)
+
+            message["Attributes"][MessageSystemAttributeName.ApproximateReceiveCount] = str(
+                sqs_message.receive_times
+            )
+            message["Attributes"][
+                MessageSystemAttributeName.ApproximateFirstReceiveTimestamp
+            ] = str(int((sqs_message.first_received or time.time()) * 1000))
+            message["ReceiptHandle"] = receipt_handle
+
+            message_filter_attributes(message, [QueueAttributeName.All])
+            message_filter_message_attributes(message, ["All"])
+
+            if message.get("MessageAttributes"):
+                message["MD5OfMessageAttributes"] = _create_message_attribute_hash(
+                    message["MessageAttributes"]
+                )
+            else:
+                # delete the value that was computed when creating the message
+                message.pop("MD5OfMessageAttributes")
+
+        return messages
+
+
 class SqsProvider(SqsApi, ServiceLifecycleHook):
     """
     LocalStack SQS Provider.
@@ -424,16 +549,21 @@ class SqsProvider(SqsApi, ServiceLifecycleHook):
         self._queue_update_worker = QueueUpdateWorker()
         self._cloudwatch_publish_worker = CloudwatchPublishWorker()
         self._cloudwatch_dispatcher = CloudwatchDispatcher()
+        self._router_rules = []
 
     @staticmethod
     def get_store(account_id: str = None, region: str = None) -> SqsStore:
         return sqs_stores[account_id or get_aws_account_id()][region or aws_stack.get_region()]
 
     def on_before_start(self):
+        self._router_rules = ROUTER.add(SqsDeveloperEndpoints())
         self._queue_update_worker.start()
         self._cloudwatch_publish_worker.start()
 
     def on_before_stop(self):
+        for rule in self._router_rules:
+            ROUTER.remove_rule(rule)
+
         self._queue_update_worker.stop()
         self._cloudwatch_publish_worker.stop()
         self._cloudwatch_dispatcher.shutdown()
@@ -809,9 +939,17 @@ class SqsProvider(SqsApi, ServiceLifecycleHook):
             wait_time_seconds = queue.wait_time_seconds
 
         num = max_number_of_messages or 1
+
         # backdoor to get all messages
         if num == -1:
             num = queue.visible.qsize()
+        elif (
+            num < 1 or num > MAX_NUMBER_OF_MESSAGES
+        ) and not SQS_DISABLE_MAX_NUMBER_OF_MESSAGE_LIMIT:
+            raise InvalidParameterValue(
+                f"Value {num} for parameter MaxNumberOfMessages is invalid. "
+                f"Reason: Must be between 1 and 10, if provided."
+            )
 
         block = True if wait_time_seconds else False
         # collect messages
@@ -1131,7 +1269,7 @@ def _create_message_attribute_hash(message_attributes) -> Optional[str]:
             )
         elif attr_value.get("BinaryValue"):
             hash.update(bytearray([BINARY_TYPE_FIELD_INDEX]))
-            decoded_binary_value = base64.b64decode(attr_value.get("BinaryValue"))
+            decoded_binary_value = attr_value.get("BinaryValue")
             MotoMessage.update_binary_length_and_value(hash, decoded_binary_value)
         # string_list_value, binary_list_value type is not implemented, reserved for the future use.
         # See https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_MessageAttributeValue.html
