@@ -2,9 +2,9 @@ import logging
 from typing import Optional
 
 from localstack import config
-from localstack.constants import TEST_AWS_ACCOUNT_ID
-from localstack.services import install
+from localstack.aws.accounts import get_aws_account_id
 from localstack.services.infra import do_run, log_startup_message
+from localstack.services.stepfunctions.packages import stepfunctions_local_package
 from localstack.utils.aws import aws_stack
 from localstack.utils.common import wait_for_port_open
 from localstack.utils.sync import retry
@@ -20,6 +20,7 @@ PROCESS_THREAD = None
 
 # TODO: pass env more explicitly
 def get_command(backend_port):
+    install_dir_stepfunctions = stepfunctions_local_package.get_installed_dir()
     cmd = (
         "cd %s; PORT=%s java "
         "-javaagent:aspectjweaver-1.9.7.jar "
@@ -27,10 +28,10 @@ def get_command(backend_port):
         "-Dcom.amazonaws.sdk.disableCertChecking -Xmx%s "
         "-jar StepFunctionsLocal.jar --aws-account %s"
     ) % (
-        install.INSTALL_DIR_STEPFUNCTIONS,
+        install_dir_stepfunctions,
         backend_port,
         MAX_HEAP_SIZE,
-        TEST_AWS_ACCOUNT_ID,
+        get_aws_account_id(),
     )
     if config.STEPFUNCTIONS_LAMBDA_ENDPOINT.lower() != "default":
         lambda_endpoint = config.STEPFUNCTIONS_LAMBDA_ENDPOINT or aws_stack.get_local_service_url(
@@ -69,7 +70,7 @@ def start_stepfunctions(asynchronous=True, persistence_path: Optional[str] = Non
     # TODO: introduce Server abstraction for StepFunctions process
     global PROCESS_THREAD
     backend_port = config.LOCAL_PORT_STEPFUNCTIONS
-    install.install_stepfunctions_local()
+    stepfunctions_local_package.install()
     cmd = get_command(backend_port)
     log_startup_message("StepFunctions")
     # TODO: change ports in stepfunctions.jar, then update here
