@@ -5,7 +5,6 @@ from glob import glob
 
 from amazon_kclpy import kcl
 
-from localstack import config
 from localstack.utils.aws import aws_stack
 from localstack.utils.files import save_file
 
@@ -53,9 +52,6 @@ def get_kcl_classpath(properties=None, paths=None):
         paths.append(dir_of_file)
     # add path of custom java code
     dir_name = os.path.dirname(os.path.realpath(__file__))
-    paths.insert(
-        0, os.path.join(config.dirs.static_libs, "amazon-kinesis-client", "aws-java-sdk-sts.jar")
-    )
     paths.insert(0, os.path.realpath(os.path.join(dir_name, "java")))
     return ":".join([p for p in paths if p != ""])
 
