@@ -13,7 +13,7 @@ from amazon_kclpy.v2 import processor
 
 from localstack import config
 from localstack.constants import LOCALHOST, LOCALSTACK_ROOT_FOLDER, LOCALSTACK_VENV_FOLDER
-from localstack.utils.aws import aws_stack
+from localstack.utils.aws import arns, aws_stack
 from localstack.utils.aws.aws_models import KinesisStream
 from localstack.utils.files import TMP_FILES, chmod_r, rm_rf, save_file
 from localstack.utils.kinesis import kclipy_helper
@@ -135,7 +135,12 @@ class KinesisProcessorThread(ShellCommandThread):
         env = aws_stack.get_environment()
         quiet = aws_stack.is_local_env(env)
         ShellCommandThread.__init__(
-            self, cmd, outfile=params["log_file"], env_vars=env_vars, quiet=quiet
+            self,
+            cmd,
+            outfile=params["log_file"],
+            env_vars=env_vars,
+            quiet=quiet,
+            name="kinesis-processor",
         )
 
     @staticmethod
@@ -147,7 +152,7 @@ class KinesisProcessorThread(ShellCommandThread):
 
 class OutputReaderThread(FuncThread):
     def __init__(self, params):
-        FuncThread.__init__(self, self.start_reading, params)
+        FuncThread.__init__(self, self.start_reading, params, name="kinesis-output-reader")
         self.buffer = []
         self.params = params
         # number of lines that make up a single log entry
@@ -278,7 +283,7 @@ def get_stream_info(
     env = aws_stack.get_environment(env)
     props_file = os.path.join(tempfile.gettempdir(), "kclipy.%s.properties" % short_uid())
     # make sure to convert stream ARN to stream name
-    stream_name = aws_stack.kinesis_stream_name(stream_name)
+    stream_name = arns.kinesis_stream_name(stream_name)
     app_name = "%s%s" % (stream_name, ddb_lease_table_suffix)
     stream_info = {
         "name": stream_name,
@@ -307,7 +312,7 @@ def get_stream_info(
 
 
 def start_kcl_client_process(
-    stream_name,
+    stream_name: str,
     listener_script,
     log_file=None,
     env=None,
@@ -327,27 +332,9 @@ def start_kcl_client_process(
         log_subscribers = []
     env = aws_stack.get_environment(env)
     # make sure to convert stream ARN to stream name
-    stream_name = aws_stack.kinesis_stream_name(stream_name)
-    # decide which credentials provider to use
-    credentialsProvider = None
-    if ("AWS_ASSUME_ROLE_ARN" in os.environ or "AWS_ASSUME_ROLE_ARN" in env_vars) and (
-        "AWS_ASSUME_ROLE_SESSION_NAME" in os.environ or "AWS_ASSUME_ROLE_SESSION_NAME" in env_vars
-    ):
-        # use special credentials provider that can assume IAM roles and handle temporary STS auth tokens
-        credentialsProvider = "cloud.localstack.DefaultSTSAssumeRoleSessionCredentialsProvider"
-        # pass through env variables to child process
-        for var_name in [
-            "AWS_ASSUME_ROLE_ARN",
-            "AWS_ASSUME_ROLE_SESSION_NAME",
-            "AWS_ACCESS_KEY_ID",
-            "AWS_SECRET_ACCESS_KEY",
-            "AWS_SESSION_TOKEN",
-        ]:
-            if var_name in os.environ and var_name not in env_vars:
-                env_vars[var_name] = os.environ[var_name]
+    stream_name = arns.kinesis_stream_name(stream_name)
     if aws_stack.is_local_env(env):
-        # need to disable CBOR protocol, enforce use of plain JSON,
-        # see https://github.com/mhart/kinesalite/issues/31
+        # disable CBOR protocol, enforce use of plain JSON
         env_vars["AWS_CBOR_DISABLE"] = "true"
     if kcl_log_level or (len(log_subscribers) > 0):
         if not log_file:
@@ -390,7 +377,6 @@ def start_kcl_client_process(
         executableName=listener_script,
         streamName=stream_name,
         applicationName=stream_info["app_name"],
-        credentialsProvider=credentialsProvider,
         region_name=region_name,
         **kwargs,
     )
